/*******************************************************************************
* File Name: Clk25KHz_Gen.c
* Version 2.10
*
* Description:
*  This file provides the source code to the API for the Clk25KHz_Gen
*  component
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "Clk25KHz_Gen.h"

uint8 Clk25KHz_Gen_initVar = 0u;


/*******************************************************************************
* Function Name: Clk25KHz_Gen_Init
********************************************************************************
*
* Summary:
*  Initialize/Restore default Clk25KHz_Gen configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_Init(void)
{

    /* Set values from customizer to CTRL */
    #if (Clk25KHz_Gen__QUAD == Clk25KHz_Gen_CONFIG)
        Clk25KHz_Gen_CONTROL_REG = Clk25KHz_Gen_CTRL_QUAD_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        Clk25KHz_Gen_TRIG_CONTROL1_REG  = Clk25KHz_Gen_QUAD_SIGNALS_MODES;

        /* Set values from customizer to INTR */
        Clk25KHz_Gen_SetInterruptMode(Clk25KHz_Gen_QUAD_INTERRUPT_MASK);
        
         /* Set other values */
        Clk25KHz_Gen_SetCounterMode(Clk25KHz_Gen_COUNT_DOWN);
        Clk25KHz_Gen_WritePeriod(Clk25KHz_Gen_QUAD_PERIOD_INIT_VALUE);
        Clk25KHz_Gen_WriteCounter(Clk25KHz_Gen_QUAD_PERIOD_INIT_VALUE);
    #endif  /* (Clk25KHz_Gen__QUAD == Clk25KHz_Gen_CONFIG) */

    #if (Clk25KHz_Gen__TIMER == Clk25KHz_Gen_CONFIG)
        Clk25KHz_Gen_CONTROL_REG = Clk25KHz_Gen_CTRL_TIMER_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        Clk25KHz_Gen_TRIG_CONTROL1_REG  = Clk25KHz_Gen_TIMER_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        Clk25KHz_Gen_SetInterruptMode(Clk25KHz_Gen_TC_INTERRUPT_MASK);
        
        /* Set other values from customizer */
        Clk25KHz_Gen_WritePeriod(Clk25KHz_Gen_TC_PERIOD_VALUE );

        #if (Clk25KHz_Gen__COMPARE == Clk25KHz_Gen_TC_COMP_CAP_MODE)
            Clk25KHz_Gen_WriteCompare(Clk25KHz_Gen_TC_COMPARE_VALUE);

            #if (1u == Clk25KHz_Gen_TC_COMPARE_SWAP)
                Clk25KHz_Gen_SetCompareSwap(1u);
                Clk25KHz_Gen_WriteCompareBuf(Clk25KHz_Gen_TC_COMPARE_BUF_VALUE);
            #endif  /* (1u == Clk25KHz_Gen_TC_COMPARE_SWAP) */
        #endif  /* (Clk25KHz_Gen__COMPARE == Clk25KHz_Gen_TC_COMP_CAP_MODE) */

        /* Initialize counter value */
        #if (Clk25KHz_Gen_CY_TCPWM_V2 && Clk25KHz_Gen_TIMER_UPDOWN_CNT_USED && !Clk25KHz_Gen_CY_TCPWM_4000)
            Clk25KHz_Gen_WriteCounter(1u);
        #elif(Clk25KHz_Gen__COUNT_DOWN == Clk25KHz_Gen_TC_COUNTER_MODE)
            Clk25KHz_Gen_WriteCounter(Clk25KHz_Gen_TC_PERIOD_VALUE);
        #else
            Clk25KHz_Gen_WriteCounter(0u);
        #endif /* (Clk25KHz_Gen_CY_TCPWM_V2 && Clk25KHz_Gen_TIMER_UPDOWN_CNT_USED && !Clk25KHz_Gen_CY_TCPWM_4000) */
    #endif  /* (Clk25KHz_Gen__TIMER == Clk25KHz_Gen_CONFIG) */

    #if (Clk25KHz_Gen__PWM_SEL == Clk25KHz_Gen_CONFIG)
        Clk25KHz_Gen_CONTROL_REG = Clk25KHz_Gen_CTRL_PWM_BASE_CONFIG;

        #if (Clk25KHz_Gen__PWM_PR == Clk25KHz_Gen_PWM_MODE)
            Clk25KHz_Gen_CONTROL_REG |= Clk25KHz_Gen_CTRL_PWM_RUN_MODE;
            Clk25KHz_Gen_WriteCounter(Clk25KHz_Gen_PWM_PR_INIT_VALUE);
        #else
            Clk25KHz_Gen_CONTROL_REG |= Clk25KHz_Gen_CTRL_PWM_ALIGN | Clk25KHz_Gen_CTRL_PWM_KILL_EVENT;
            
            /* Initialize counter value */
            #if (Clk25KHz_Gen_CY_TCPWM_V2 && Clk25KHz_Gen_PWM_UPDOWN_CNT_USED && !Clk25KHz_Gen_CY_TCPWM_4000)
                Clk25KHz_Gen_WriteCounter(1u);
            #elif (Clk25KHz_Gen__RIGHT == Clk25KHz_Gen_PWM_ALIGN)
                Clk25KHz_Gen_WriteCounter(Clk25KHz_Gen_PWM_PERIOD_VALUE);
            #else 
                Clk25KHz_Gen_WriteCounter(0u);
            #endif  /* (Clk25KHz_Gen_CY_TCPWM_V2 && Clk25KHz_Gen_PWM_UPDOWN_CNT_USED && !Clk25KHz_Gen_CY_TCPWM_4000) */
        #endif  /* (Clk25KHz_Gen__PWM_PR == Clk25KHz_Gen_PWM_MODE) */

        #if (Clk25KHz_Gen__PWM_DT == Clk25KHz_Gen_PWM_MODE)
            Clk25KHz_Gen_CONTROL_REG |= Clk25KHz_Gen_CTRL_PWM_DEAD_TIME_CYCLE;
        #endif  /* (Clk25KHz_Gen__PWM_DT == Clk25KHz_Gen_PWM_MODE) */

        #if (Clk25KHz_Gen__PWM == Clk25KHz_Gen_PWM_MODE)
            Clk25KHz_Gen_CONTROL_REG |= Clk25KHz_Gen_CTRL_PWM_PRESCALER;
        #endif  /* (Clk25KHz_Gen__PWM == Clk25KHz_Gen_PWM_MODE) */

        /* Set values from customizer to CTRL1 */
        Clk25KHz_Gen_TRIG_CONTROL1_REG  = Clk25KHz_Gen_PWM_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        Clk25KHz_Gen_SetInterruptMode(Clk25KHz_Gen_PWM_INTERRUPT_MASK);

        /* Set values from customizer to CTRL2 */
        #if (Clk25KHz_Gen__PWM_PR == Clk25KHz_Gen_PWM_MODE)
            Clk25KHz_Gen_TRIG_CONTROL2_REG =
                    (Clk25KHz_Gen_CC_MATCH_NO_CHANGE    |
                    Clk25KHz_Gen_OVERLOW_NO_CHANGE      |
                    Clk25KHz_Gen_UNDERFLOW_NO_CHANGE);
        #else
            #if (Clk25KHz_Gen__LEFT == Clk25KHz_Gen_PWM_ALIGN)
                Clk25KHz_Gen_TRIG_CONTROL2_REG = Clk25KHz_Gen_PWM_MODE_LEFT;
            #endif  /* ( Clk25KHz_Gen_PWM_LEFT == Clk25KHz_Gen_PWM_ALIGN) */

            #if (Clk25KHz_Gen__RIGHT == Clk25KHz_Gen_PWM_ALIGN)
                Clk25KHz_Gen_TRIG_CONTROL2_REG = Clk25KHz_Gen_PWM_MODE_RIGHT;
            #endif  /* ( Clk25KHz_Gen_PWM_RIGHT == Clk25KHz_Gen_PWM_ALIGN) */

            #if (Clk25KHz_Gen__CENTER == Clk25KHz_Gen_PWM_ALIGN)
                Clk25KHz_Gen_TRIG_CONTROL2_REG = Clk25KHz_Gen_PWM_MODE_CENTER;
            #endif  /* ( Clk25KHz_Gen_PWM_CENTER == Clk25KHz_Gen_PWM_ALIGN) */

            #if (Clk25KHz_Gen__ASYMMETRIC == Clk25KHz_Gen_PWM_ALIGN)
                Clk25KHz_Gen_TRIG_CONTROL2_REG = Clk25KHz_Gen_PWM_MODE_ASYM;
            #endif  /* (Clk25KHz_Gen__ASYMMETRIC == Clk25KHz_Gen_PWM_ALIGN) */
        #endif  /* (Clk25KHz_Gen__PWM_PR == Clk25KHz_Gen_PWM_MODE) */

        /* Set other values from customizer */
        Clk25KHz_Gen_WritePeriod(Clk25KHz_Gen_PWM_PERIOD_VALUE );
        Clk25KHz_Gen_WriteCompare(Clk25KHz_Gen_PWM_COMPARE_VALUE);

        #if (1u == Clk25KHz_Gen_PWM_COMPARE_SWAP)
            Clk25KHz_Gen_SetCompareSwap(1u);
            Clk25KHz_Gen_WriteCompareBuf(Clk25KHz_Gen_PWM_COMPARE_BUF_VALUE);
        #endif  /* (1u == Clk25KHz_Gen_PWM_COMPARE_SWAP) */

        #if (1u == Clk25KHz_Gen_PWM_PERIOD_SWAP)
            Clk25KHz_Gen_SetPeriodSwap(1u);
            Clk25KHz_Gen_WritePeriodBuf(Clk25KHz_Gen_PWM_PERIOD_BUF_VALUE);
        #endif  /* (1u == Clk25KHz_Gen_PWM_PERIOD_SWAP) */
    #endif  /* (Clk25KHz_Gen__PWM_SEL == Clk25KHz_Gen_CONFIG) */
    
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_Enable
********************************************************************************
*
* Summary:
*  Enables the Clk25KHz_Gen.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_Enable(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    Clk25KHz_Gen_BLOCK_CONTROL_REG |= Clk25KHz_Gen_MASK;
    CyExitCriticalSection(enableInterrupts);

    /* Start Timer or PWM if start input is absent */
    #if (Clk25KHz_Gen__PWM_SEL == Clk25KHz_Gen_CONFIG)
        #if (0u == Clk25KHz_Gen_PWM_START_SIGNAL_PRESENT)
            Clk25KHz_Gen_TriggerCommand(Clk25KHz_Gen_MASK, Clk25KHz_Gen_CMD_START);
        #endif /* (0u == Clk25KHz_Gen_PWM_START_SIGNAL_PRESENT) */
    #endif /* (Clk25KHz_Gen__PWM_SEL == Clk25KHz_Gen_CONFIG) */

    #if (Clk25KHz_Gen__TIMER == Clk25KHz_Gen_CONFIG)
        #if (0u == Clk25KHz_Gen_TC_START_SIGNAL_PRESENT)
            Clk25KHz_Gen_TriggerCommand(Clk25KHz_Gen_MASK, Clk25KHz_Gen_CMD_START);
        #endif /* (0u == Clk25KHz_Gen_TC_START_SIGNAL_PRESENT) */
    #endif /* (Clk25KHz_Gen__TIMER == Clk25KHz_Gen_CONFIG) */
    
    #if (Clk25KHz_Gen__QUAD == Clk25KHz_Gen_CONFIG)
        #if (0u != Clk25KHz_Gen_QUAD_AUTO_START)
            Clk25KHz_Gen_TriggerCommand(Clk25KHz_Gen_MASK, Clk25KHz_Gen_CMD_RELOAD);
        #endif /* (0u != Clk25KHz_Gen_QUAD_AUTO_START) */
    #endif  /* (Clk25KHz_Gen__QUAD == Clk25KHz_Gen_CONFIG) */
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_Start
********************************************************************************
*
* Summary:
*  Initializes the Clk25KHz_Gen with default customizer
*  values when called the first time and enables the Clk25KHz_Gen.
*  For subsequent calls the configuration is left unchanged and the component is
*  just enabled.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  Clk25KHz_Gen_initVar: global variable is used to indicate initial
*  configuration of this component.  The variable is initialized to zero and set
*  to 1 the first time Clk25KHz_Gen_Start() is called. This allows
*  enabling/disabling a component without re-initialization in all subsequent
*  calls to the Clk25KHz_Gen_Start() routine.
*
*******************************************************************************/
void Clk25KHz_Gen_Start(void)
{
    if (0u == Clk25KHz_Gen_initVar)
    {
        Clk25KHz_Gen_Init();
        Clk25KHz_Gen_initVar = 1u;
    }

    Clk25KHz_Gen_Enable();
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_Stop
********************************************************************************
*
* Summary:
*  Disables the Clk25KHz_Gen.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_Stop(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Clk25KHz_Gen_BLOCK_CONTROL_REG &= (uint32)~Clk25KHz_Gen_MASK;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_SetMode
********************************************************************************
*
* Summary:
*  Sets the operation mode of the Clk25KHz_Gen. This function is used when
*  configured as a generic Clk25KHz_Gen and the actual mode of operation is
*  set at runtime. The mode must be set while the component is disabled.
*
* Parameters:
*  mode: Mode for the Clk25KHz_Gen to operate in
*   Values:
*   - Clk25KHz_Gen_MODE_TIMER_COMPARE - Timer / Counter with
*                                                 compare capability
*         - Clk25KHz_Gen_MODE_TIMER_CAPTURE - Timer / Counter with
*                                                 capture capability
*         - Clk25KHz_Gen_MODE_QUAD - Quadrature decoder
*         - Clk25KHz_Gen_MODE_PWM - PWM
*         - Clk25KHz_Gen_MODE_PWM_DT - PWM with dead time
*         - Clk25KHz_Gen_MODE_PWM_PR - PWM with pseudo random capability
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_SetMode(uint32 mode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Clk25KHz_Gen_CONTROL_REG &= (uint32)~Clk25KHz_Gen_MODE_MASK;
    Clk25KHz_Gen_CONTROL_REG |= mode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_SetQDMode
********************************************************************************
*
* Summary:
*  Sets the the Quadrature Decoder to one of the 3 supported modes.
*  Its functionality is only applicable to Quadrature Decoder operation.
*
* Parameters:
*  qdMode: Quadrature Decoder mode
*   Values:
*         - Clk25KHz_Gen_MODE_X1 - Counts on phi 1 rising
*         - Clk25KHz_Gen_MODE_X2 - Counts on both edges of phi1 (2x faster)
*         - Clk25KHz_Gen_MODE_X4 - Counts on both edges of phi1 and phi2
*                                        (4x faster)
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_SetQDMode(uint32 qdMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Clk25KHz_Gen_CONTROL_REG &= (uint32)~Clk25KHz_Gen_QUAD_MODE_MASK;
    Clk25KHz_Gen_CONTROL_REG |= qdMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_SetPrescaler
********************************************************************************
*
* Summary:
*  Sets the prescaler value that is applied to the clock input.  Not applicable
*  to a PWM with the dead time mode or Quadrature Decoder mode.
*
* Parameters:
*  prescaler: Prescaler divider value
*   Values:
*         - Clk25KHz_Gen_PRESCALE_DIVBY1    - Divide by 1 (no prescaling)
*         - Clk25KHz_Gen_PRESCALE_DIVBY2    - Divide by 2
*         - Clk25KHz_Gen_PRESCALE_DIVBY4    - Divide by 4
*         - Clk25KHz_Gen_PRESCALE_DIVBY8    - Divide by 8
*         - Clk25KHz_Gen_PRESCALE_DIVBY16   - Divide by 16
*         - Clk25KHz_Gen_PRESCALE_DIVBY32   - Divide by 32
*         - Clk25KHz_Gen_PRESCALE_DIVBY64   - Divide by 64
*         - Clk25KHz_Gen_PRESCALE_DIVBY128  - Divide by 128
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_SetPrescaler(uint32 prescaler)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Clk25KHz_Gen_CONTROL_REG &= (uint32)~Clk25KHz_Gen_PRESCALER_MASK;
    Clk25KHz_Gen_CONTROL_REG |= prescaler;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_SetOneShot
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the Clk25KHz_Gen runs
*  continuously or stops when terminal count is reached.  By default the
*  Clk25KHz_Gen operates in the continuous mode.
*
* Parameters:
*  oneShotEnable
*   Values:
*     - 0 - Continuous
*     - 1 - Enable One Shot
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_SetOneShot(uint32 oneShotEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Clk25KHz_Gen_CONTROL_REG &= (uint32)~Clk25KHz_Gen_ONESHOT_MASK;
    Clk25KHz_Gen_CONTROL_REG |= ((uint32)((oneShotEnable & Clk25KHz_Gen_1BIT_MASK) <<
                                                               Clk25KHz_Gen_ONESHOT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_SetPWMMode
********************************************************************************
*
* Summary:
*  Writes the control register that determines what mode of operation the PWM
*  output lines are driven in.  There is a setting for what to do on a
*  comparison match (CC_MATCH), on an overflow (OVERFLOW) and on an underflow
*  (UNDERFLOW).  The value for each of the three must be ORed together to form
*  the mode.
*
* Parameters:
*  modeMask: A combination of three mode settings.  Mask must include a value
*  for each of the three or use one of the preconfigured PWM settings.
*   Values:
*     - CC_MATCH_SET        - Set on comparison match
*     - CC_MATCH_CLEAR      - Clear on comparison match
*     - CC_MATCH_INVERT     - Invert on comparison match
*     - CC_MATCH_NO_CHANGE  - No change on comparison match
*     - OVERLOW_SET         - Set on overflow
*     - OVERLOW_CLEAR       - Clear on  overflow
*     - OVERLOW_INVERT      - Invert on overflow
*     - OVERLOW_NO_CHANGE   - No change on overflow
*     - UNDERFLOW_SET       - Set on underflow
*     - UNDERFLOW_CLEAR     - Clear on underflow
*     - UNDERFLOW_INVERT    - Invert on underflow
*     - UNDERFLOW_NO_CHANGE - No change on underflow
*     - PWM_MODE_LEFT       - Setting for left aligned PWM.  Should be combined
*                             with up counting mode
*     - PWM_MODE_RIGHT      - Setting for right aligned PWM.  Should be combined
*                             with down counting mode
*     - PWM_MODE_CENTER     - Setting for center aligned PWM.  Should be
*                             combined with up/down 0 mode
*     - PWM_MODE_ASYM       - Setting for asymmetric PWM.  Should be combined
*                             with up/down 1 mode
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_SetPWMMode(uint32 modeMask)
{
    Clk25KHz_Gen_TRIG_CONTROL2_REG = (modeMask & Clk25KHz_Gen_6BIT_MASK);
}



/*******************************************************************************
* Function Name: Clk25KHz_Gen_SetPWMSyncKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes asynchronous or synchronous kill operation.  By default the kill
*  operation is asynchronous.  This functionality is only applicable to the PWM
*  and PWM with dead time modes.
*
*  For Synchronous mode the kill signal disables both the line and line_n
*  signals until the next terminal count.
*
*  For Asynchronous mode the kill signal disables both the line and line_n
*  signals when the kill signal is present.  This mode should only be used
*  when the kill signal (stop input) is configured in the pass through mode
*  (Level sensitive signal).

*
* Parameters:
*  syncKillEnable
*   Values:
*     - 0 - Asynchronous
*     - 1 - Synchronous
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_SetPWMSyncKill(uint32 syncKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Clk25KHz_Gen_CONTROL_REG &= (uint32)~Clk25KHz_Gen_PWM_SYNC_KILL_MASK;
    Clk25KHz_Gen_CONTROL_REG |= ((uint32)((syncKillEnable & Clk25KHz_Gen_1BIT_MASK)  <<
                                               Clk25KHz_Gen_PWM_SYNC_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_SetPWMStopOnKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes the PWM counter to stop.  By default the kill operation does not stop
*  the counter.  This functionality is only applicable to the three PWM modes.
*
*
* Parameters:
*  stopOnKillEnable
*   Values:
*     - 0 - Don't stop
*     - 1 - Stop
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_SetPWMStopOnKill(uint32 stopOnKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Clk25KHz_Gen_CONTROL_REG &= (uint32)~Clk25KHz_Gen_PWM_STOP_KILL_MASK;
    Clk25KHz_Gen_CONTROL_REG |= ((uint32)((stopOnKillEnable & Clk25KHz_Gen_1BIT_MASK)  <<
                                                         Clk25KHz_Gen_PWM_STOP_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_SetPWMDeadTime
********************************************************************************
*
* Summary:
*  Writes the dead time control value.  This value delays the rising edge of
*  both the line and line_n signals the designated number of cycles resulting
*  in both signals being inactive for that many cycles.  This functionality is
*  only applicable to the PWM in the dead time mode.

*
* Parameters:
*  Dead time to insert
*   Values: 0 to 255
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_SetPWMDeadTime(uint32 deadTime)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Clk25KHz_Gen_CONTROL_REG &= (uint32)~Clk25KHz_Gen_PRESCALER_MASK;
    Clk25KHz_Gen_CONTROL_REG |= ((uint32)((deadTime & Clk25KHz_Gen_8BIT_MASK) <<
                                                          Clk25KHz_Gen_PRESCALER_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_SetPWMInvert
********************************************************************************
*
* Summary:
*  Writes the bits that control whether the line and line_n outputs are
*  inverted from their normal output values.  This functionality is only
*  applicable to the three PWM modes.
*
* Parameters:
*  mask: Mask of outputs to invert.
*   Values:
*         - Clk25KHz_Gen_INVERT_LINE   - Inverts the line output
*         - Clk25KHz_Gen_INVERT_LINE_N - Inverts the line_n output
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_SetPWMInvert(uint32 mask)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Clk25KHz_Gen_CONTROL_REG &= (uint32)~Clk25KHz_Gen_INV_OUT_MASK;
    Clk25KHz_Gen_CONTROL_REG |= mask;

    CyExitCriticalSection(enableInterrupts);
}



/*******************************************************************************
* Function Name: Clk25KHz_Gen_WriteCounter
********************************************************************************
*
* Summary:
*  Writes a new 16bit counter value directly into the counter register, thus
*  setting the counter (not the period) to the value written. It is not
*  advised to write to this field when the counter is running.
*
* Parameters:
*  count: value to write
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_WriteCounter(uint32 count)
{
    Clk25KHz_Gen_COUNTER_REG = (count & Clk25KHz_Gen_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_ReadCounter
********************************************************************************
*
* Summary:
*  Reads the current counter value.
*
* Parameters:
*  None
*
* Return:
*  Current counter value
*
*******************************************************************************/
uint32 Clk25KHz_Gen_ReadCounter(void)
{
    return (Clk25KHz_Gen_COUNTER_REG & Clk25KHz_Gen_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_SetCounterMode
********************************************************************************
*
* Summary:
*  Sets the counter mode.  Applicable to all modes except Quadrature Decoder
*  and the PWM with a pseudo random output.
*
* Parameters:
*  counterMode: Enumerated counter type values
*   Values:
*     - Clk25KHz_Gen_COUNT_UP       - Counts up
*     - Clk25KHz_Gen_COUNT_DOWN     - Counts down
*     - Clk25KHz_Gen_COUNT_UPDOWN0  - Counts up and down. Terminal count
*                                         generated when counter reaches 0
*     - Clk25KHz_Gen_COUNT_UPDOWN1  - Counts up and down. Terminal count
*                                         generated both when counter reaches 0
*                                         and period
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_SetCounterMode(uint32 counterMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Clk25KHz_Gen_CONTROL_REG &= (uint32)~Clk25KHz_Gen_UPDOWN_MASK;
    Clk25KHz_Gen_CONTROL_REG |= counterMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_WritePeriod
********************************************************************************
*
* Summary:
*  Writes the 16 bit period register with the new period value.
*  To cause the counter to count for N cycles this register should be written
*  with N-1 (counts from 0 to period inclusive).
*
* Parameters:
*  period: Period value
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_WritePeriod(uint32 period)
{
    Clk25KHz_Gen_PERIOD_REG = (period & Clk25KHz_Gen_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_ReadPeriod
********************************************************************************
*
* Summary:
*  Reads the 16 bit period register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 Clk25KHz_Gen_ReadPeriod(void)
{
    return (Clk25KHz_Gen_PERIOD_REG & Clk25KHz_Gen_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_SetCompareSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the compare registers are
*  swapped. When enabled in the Timer/Counter mode(without capture) the swap
*  occurs at a TC event. In the PWM mode the swap occurs at the next TC event
*  following a hardware switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_SetCompareSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Clk25KHz_Gen_CONTROL_REG &= (uint32)~Clk25KHz_Gen_RELOAD_CC_MASK;
    Clk25KHz_Gen_CONTROL_REG |= (swapEnable & Clk25KHz_Gen_1BIT_MASK);

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_WritePeriodBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit period buf register with the new period value.
*
* Parameters:
*  periodBuf: Period value
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_WritePeriodBuf(uint32 periodBuf)
{
    Clk25KHz_Gen_PERIOD_BUF_REG = (periodBuf & Clk25KHz_Gen_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_ReadPeriodBuf
********************************************************************************
*
* Summary:
*  Reads the 16 bit period buf register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 Clk25KHz_Gen_ReadPeriodBuf(void)
{
    return (Clk25KHz_Gen_PERIOD_BUF_REG & Clk25KHz_Gen_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_SetPeriodSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the period registers are
*  swapped. When enabled in Timer/Counter mode the swap occurs at a TC event.
*  In the PWM mode the swap occurs at the next TC event following a hardware
*  switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_SetPeriodSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Clk25KHz_Gen_CONTROL_REG &= (uint32)~Clk25KHz_Gen_RELOAD_PERIOD_MASK;
    Clk25KHz_Gen_CONTROL_REG |= ((uint32)((swapEnable & Clk25KHz_Gen_1BIT_MASK) <<
                                                            Clk25KHz_Gen_RELOAD_PERIOD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_WriteCompare
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compare: Compare value
*
* Return:
*  None
*
* Note:
*  It is not recommended to use the value equal to "0" or equal to 
*  "period value" in Center or Asymmetric align PWM modes on the 
*  PSoC 4100/PSoC 4200 devices.
*  PSoC 4000 devices write the 16 bit compare register with the decremented 
*  compare value in the Up counting mode (except 0x0u), and the incremented 
*  compare value in the Down counting mode (except 0xFFFFu).
*
*******************************************************************************/
void Clk25KHz_Gen_WriteCompare(uint32 compare)
{
    #if (Clk25KHz_Gen_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (Clk25KHz_Gen_CY_TCPWM_4000) */

    #if (Clk25KHz_Gen_CY_TCPWM_4000)
        currentMode = ((Clk25KHz_Gen_CONTROL_REG & Clk25KHz_Gen_UPDOWN_MASK) >> Clk25KHz_Gen_UPDOWN_SHIFT);

        if (((uint32)Clk25KHz_Gen__COUNT_DOWN == currentMode) && (0xFFFFu != compare))
        {
            compare++;
        }
        else if (((uint32)Clk25KHz_Gen__COUNT_UP == currentMode) && (0u != compare))
        {
            compare--;
        }
        else
        {
        }
        
    
    #endif /* (Clk25KHz_Gen_CY_TCPWM_4000) */
    
    Clk25KHz_Gen_COMP_CAP_REG = (compare & Clk25KHz_Gen_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_ReadCompare
********************************************************************************
*
* Summary:
*  Reads the compare register. Not applicable for Timer/Counter with Capture
*  or in Quadrature Decoder modes.
*  PSoC 4000 devices read the incremented compare register value in the 
*  Up counting mode (except 0xFFFFu), and the decremented value in the 
*  Down counting mode (except 0x0u).
*
* Parameters:
*  None
*
* Return:
*  Compare value
*
* Note:
*  PSoC 4000 devices read the incremented compare register value in the 
*  Up counting mode (except 0xFFFFu), and the decremented value in the 
*  Down counting mode (except 0x0u).
*
*******************************************************************************/
uint32 Clk25KHz_Gen_ReadCompare(void)
{
    #if (Clk25KHz_Gen_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (Clk25KHz_Gen_CY_TCPWM_4000) */

    #if (Clk25KHz_Gen_CY_TCPWM_4000)
        currentMode = ((Clk25KHz_Gen_CONTROL_REG & Clk25KHz_Gen_UPDOWN_MASK) >> Clk25KHz_Gen_UPDOWN_SHIFT);
        
        regVal = Clk25KHz_Gen_COMP_CAP_REG;
        
        if (((uint32)Clk25KHz_Gen__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)Clk25KHz_Gen__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & Clk25KHz_Gen_16BIT_MASK);
    #else
        return (Clk25KHz_Gen_COMP_CAP_REG & Clk25KHz_Gen_16BIT_MASK);
    #endif /* (Clk25KHz_Gen_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_WriteCompareBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare buffer register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compareBuf: Compare value
*
* Return:
*  None
*
* Note:
*  It is not recommended to use the value equal to "0" or equal to 
*  "period value" in Center or Asymmetric align PWM modes on the 
*  PSoC 4100/PSoC 4200 devices.
*  PSoC 4000 devices write the 16 bit compare register with the decremented 
*  compare value in the Up counting mode (except 0x0u), and the incremented 
*  compare value in the Down counting mode (except 0xFFFFu).
*
*******************************************************************************/
void Clk25KHz_Gen_WriteCompareBuf(uint32 compareBuf)
{
    #if (Clk25KHz_Gen_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (Clk25KHz_Gen_CY_TCPWM_4000) */

    #if (Clk25KHz_Gen_CY_TCPWM_4000)
        currentMode = ((Clk25KHz_Gen_CONTROL_REG & Clk25KHz_Gen_UPDOWN_MASK) >> Clk25KHz_Gen_UPDOWN_SHIFT);

        if (((uint32)Clk25KHz_Gen__COUNT_DOWN == currentMode) && (0xFFFFu != compareBuf))
        {
            compareBuf++;
        }
        else if (((uint32)Clk25KHz_Gen__COUNT_UP == currentMode) && (0u != compareBuf))
        {
            compareBuf --;
        }
        else
        {
        }
    #endif /* (Clk25KHz_Gen_CY_TCPWM_4000) */
    
    Clk25KHz_Gen_COMP_CAP_BUF_REG = (compareBuf & Clk25KHz_Gen_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_ReadCompareBuf
********************************************************************************
*
* Summary:
*  Reads the compare buffer register. Not applicable for Timer/Counter with
*  Capture or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare buffer value
*
* Note:
*  PSoC 4000 devices read the incremented compare register value in the 
*  Up counting mode (except 0xFFFFu), and the decremented value in the 
*  Down counting mode (except 0x0u).
*
*******************************************************************************/
uint32 Clk25KHz_Gen_ReadCompareBuf(void)
{
    #if (Clk25KHz_Gen_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (Clk25KHz_Gen_CY_TCPWM_4000) */

    #if (Clk25KHz_Gen_CY_TCPWM_4000)
        currentMode = ((Clk25KHz_Gen_CONTROL_REG & Clk25KHz_Gen_UPDOWN_MASK) >> Clk25KHz_Gen_UPDOWN_SHIFT);

        regVal = Clk25KHz_Gen_COMP_CAP_BUF_REG;
        
        if (((uint32)Clk25KHz_Gen__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)Clk25KHz_Gen__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & Clk25KHz_Gen_16BIT_MASK);
    #else
        return (Clk25KHz_Gen_COMP_CAP_BUF_REG & Clk25KHz_Gen_16BIT_MASK);
    #endif /* (Clk25KHz_Gen_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_ReadCapture
********************************************************************************
*
* Summary:
*  Reads the captured counter value. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture value
*
*******************************************************************************/
uint32 Clk25KHz_Gen_ReadCapture(void)
{
    return (Clk25KHz_Gen_COMP_CAP_REG & Clk25KHz_Gen_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_ReadCaptureBuf
********************************************************************************
*
* Summary:
*  Reads the capture buffer register. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture buffer value
*
*******************************************************************************/
uint32 Clk25KHz_Gen_ReadCaptureBuf(void)
{
    return (Clk25KHz_Gen_COMP_CAP_BUF_REG & Clk25KHz_Gen_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_SetCaptureMode
********************************************************************************
*
* Summary:
*  Sets the capture trigger mode. For PWM mode this is the switch input.
*  This input is not applicable to the Timer/Counter without Capture and
*  Quadrature Decoder modes.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - Clk25KHz_Gen_TRIG_LEVEL     - Level
*     - Clk25KHz_Gen_TRIG_RISING    - Rising edge
*     - Clk25KHz_Gen_TRIG_FALLING   - Falling edge
*     - Clk25KHz_Gen_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_SetCaptureMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Clk25KHz_Gen_TRIG_CONTROL1_REG &= (uint32)~Clk25KHz_Gen_CAPTURE_MASK;
    Clk25KHz_Gen_TRIG_CONTROL1_REG |= triggerMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_SetReloadMode
********************************************************************************
*
* Summary:
*  Sets the reload trigger mode. For Quadrature Decoder mode this is the index
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - Clk25KHz_Gen_TRIG_LEVEL     - Level
*     - Clk25KHz_Gen_TRIG_RISING    - Rising edge
*     - Clk25KHz_Gen_TRIG_FALLING   - Falling edge
*     - Clk25KHz_Gen_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_SetReloadMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Clk25KHz_Gen_TRIG_CONTROL1_REG &= (uint32)~Clk25KHz_Gen_RELOAD_MASK;
    Clk25KHz_Gen_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << Clk25KHz_Gen_RELOAD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_SetStartMode
********************************************************************************
*
* Summary:
*  Sets the start trigger mode. For Quadrature Decoder mode this is the
*  phiB input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - Clk25KHz_Gen_TRIG_LEVEL     - Level
*     - Clk25KHz_Gen_TRIG_RISING    - Rising edge
*     - Clk25KHz_Gen_TRIG_FALLING   - Falling edge
*     - Clk25KHz_Gen_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_SetStartMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Clk25KHz_Gen_TRIG_CONTROL1_REG &= (uint32)~Clk25KHz_Gen_START_MASK;
    Clk25KHz_Gen_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << Clk25KHz_Gen_START_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_SetStopMode
********************************************************************************
*
* Summary:
*  Sets the stop trigger mode. For PWM mode this is the kill input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - Clk25KHz_Gen_TRIG_LEVEL     - Level
*     - Clk25KHz_Gen_TRIG_RISING    - Rising edge
*     - Clk25KHz_Gen_TRIG_FALLING   - Falling edge
*     - Clk25KHz_Gen_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_SetStopMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Clk25KHz_Gen_TRIG_CONTROL1_REG &= (uint32)~Clk25KHz_Gen_STOP_MASK;
    Clk25KHz_Gen_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << Clk25KHz_Gen_STOP_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_SetCountMode
********************************************************************************
*
* Summary:
*  Sets the count trigger mode. For Quadrature Decoder mode this is the phiA
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - Clk25KHz_Gen_TRIG_LEVEL     - Level
*     - Clk25KHz_Gen_TRIG_RISING    - Rising edge
*     - Clk25KHz_Gen_TRIG_FALLING   - Falling edge
*     - Clk25KHz_Gen_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_SetCountMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Clk25KHz_Gen_TRIG_CONTROL1_REG &= (uint32)~Clk25KHz_Gen_COUNT_MASK;
    Clk25KHz_Gen_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << Clk25KHz_Gen_COUNT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_TriggerCommand
********************************************************************************
*
* Summary:
*  Triggers the designated command to occur on the designated TCPWM instances.
*  The mask can be used to apply this command simultaneously to more than one
*  instance.  This allows multiple TCPWM instances to be synchronized.
*
* Parameters:
*  mask: A combination of mask bits for each instance of the TCPWM that the
*        command should apply to.  This function from one instance can be used
*        to apply the command to any of the instances in the design.
*        The mask value for a specific instance is available with the MASK
*        define.
*  command: Enumerated command values. Capture command only applicable for
*           Timer/Counter with Capture and PWM modes.
*   Values:
*     - Clk25KHz_Gen_CMD_CAPTURE    - Trigger Capture/Switch command
*     - Clk25KHz_Gen_CMD_RELOAD     - Trigger Reload/Index command
*     - Clk25KHz_Gen_CMD_STOP       - Trigger Stop/Kill command
*     - Clk25KHz_Gen_CMD_START      - Trigger Start/phiB command
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_TriggerCommand(uint32 mask, uint32 command)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Clk25KHz_Gen_COMMAND_REG = ((uint32)(mask << command));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_ReadStatus
********************************************************************************
*
* Summary:
*  Reads the status of the Clk25KHz_Gen.
*
* Parameters:
*  None
*
* Return:
*  Status
*   Values:
*     - Clk25KHz_Gen_STATUS_DOWN    - Set if counting down
*     - Clk25KHz_Gen_STATUS_RUNNING - Set if counter is running
*
*******************************************************************************/
uint32 Clk25KHz_Gen_ReadStatus(void)
{
    return ((Clk25KHz_Gen_STATUS_REG >> Clk25KHz_Gen_RUNNING_STATUS_SHIFT) |
            (Clk25KHz_Gen_STATUS_REG & Clk25KHz_Gen_STATUS_DOWN));
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_SetInterruptMode
********************************************************************************
*
* Summary:
*  Sets the interrupt mask to control which interrupt
*  requests generate the interrupt signal.
*
* Parameters:
*   interruptMask: Mask of bits to be enabled
*   Values:
*     - Clk25KHz_Gen_INTR_MASK_TC       - Terminal count mask
*     - Clk25KHz_Gen_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_SetInterruptMode(uint32 interruptMask)
{
    Clk25KHz_Gen_INTERRUPT_MASK_REG =  interruptMask;
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_GetInterruptSourceMasked
********************************************************************************
*
* Summary:
*  Gets the interrupt requests masked by the interrupt mask.
*
* Parameters:
*   None
*
* Return:
*  Masked interrupt source
*   Values:
*     - Clk25KHz_Gen_INTR_MASK_TC       - Terminal count mask
*     - Clk25KHz_Gen_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 Clk25KHz_Gen_GetInterruptSourceMasked(void)
{
    return (Clk25KHz_Gen_INTERRUPT_MASKED_REG);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_GetInterruptSource
********************************************************************************
*
* Summary:
*  Gets the interrupt requests (without masking).
*
* Parameters:
*  None
*
* Return:
*  Interrupt request value
*   Values:
*     - Clk25KHz_Gen_INTR_MASK_TC       - Terminal count mask
*     - Clk25KHz_Gen_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 Clk25KHz_Gen_GetInterruptSource(void)
{
    return (Clk25KHz_Gen_INTERRUPT_REQ_REG);
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_ClearInterrupt
********************************************************************************
*
* Summary:
*  Clears the interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to clear
*   Values:
*     - Clk25KHz_Gen_INTR_MASK_TC       - Terminal count mask
*     - Clk25KHz_Gen_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_ClearInterrupt(uint32 interruptMask)
{
    Clk25KHz_Gen_INTERRUPT_REQ_REG = interruptMask;
}


/*******************************************************************************
* Function Name: Clk25KHz_Gen_SetInterrupt
********************************************************************************
*
* Summary:
*  Sets a software interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to set
*   Values:
*     - Clk25KHz_Gen_INTR_MASK_TC       - Terminal count mask
*     - Clk25KHz_Gen_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void Clk25KHz_Gen_SetInterrupt(uint32 interruptMask)
{
    Clk25KHz_Gen_INTERRUPT_SET_REG = interruptMask;
}


/* [] END OF FILE */
