/*******************************************************************************
* File Name: Clock_In_25KHz.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_Clock_In_25KHz_H) /* Pins Clock_In_25KHz_H */
#define CY_PINS_Clock_In_25KHz_H

#include "cytypes.h"
#include "cyfitter.h"
#include "Clock_In_25KHz_aliases.h"


/***************************************
*     Data Struct Definitions
***************************************/

/**
* \addtogroup group_structures
* @{
*/
    
/* Structure for sleep mode support */
typedef struct
{
    uint32 pcState; /**< State of the port control register */
    uint32 sioState; /**< State of the SIO configuration */
    uint32 usbState; /**< State of the USBIO regulator */
} Clock_In_25KHz_BACKUP_STRUCT;

/** @} structures */


/***************************************
*        Function Prototypes             
***************************************/
/**
* \addtogroup group_general
* @{
*/
uint8   Clock_In_25KHz_Read(void);
void    Clock_In_25KHz_Write(uint8 value);
uint8   Clock_In_25KHz_ReadDataReg(void);
#if defined(Clock_In_25KHz__PC) || (CY_PSOC4_4200L) 
    void    Clock_In_25KHz_SetDriveMode(uint8 mode);
#endif
void    Clock_In_25KHz_SetInterruptMode(uint16 position, uint16 mode);
uint8   Clock_In_25KHz_ClearInterrupt(void);
/** @} general */

/**
* \addtogroup group_power
* @{
*/
void Clock_In_25KHz_Sleep(void); 
void Clock_In_25KHz_Wakeup(void);
/** @} power */


/***************************************
*           API Constants        
***************************************/
#if defined(Clock_In_25KHz__PC) || (CY_PSOC4_4200L) 
    /* Drive Modes */
    #define Clock_In_25KHz_DRIVE_MODE_BITS        (3)
    #define Clock_In_25KHz_DRIVE_MODE_IND_MASK    (0xFFFFFFFFu >> (32 - Clock_In_25KHz_DRIVE_MODE_BITS))

    /**
    * \addtogroup group_constants
    * @{
    */
        /** \addtogroup driveMode Drive mode constants
         * \brief Constants to be passed as "mode" parameter in the Clock_In_25KHz_SetDriveMode() function.
         *  @{
         */
        #define Clock_In_25KHz_DM_ALG_HIZ         (0x00u) /**< \brief High Impedance Analog   */
        #define Clock_In_25KHz_DM_DIG_HIZ         (0x01u) /**< \brief High Impedance Digital  */
        #define Clock_In_25KHz_DM_RES_UP          (0x02u) /**< \brief Resistive Pull Up       */
        #define Clock_In_25KHz_DM_RES_DWN         (0x03u) /**< \brief Resistive Pull Down     */
        #define Clock_In_25KHz_DM_OD_LO           (0x04u) /**< \brief Open Drain, Drives Low  */
        #define Clock_In_25KHz_DM_OD_HI           (0x05u) /**< \brief Open Drain, Drives High */
        #define Clock_In_25KHz_DM_STRONG          (0x06u) /**< \brief Strong Drive            */
        #define Clock_In_25KHz_DM_RES_UPDWN       (0x07u) /**< \brief Resistive Pull Up/Down  */
        /** @} driveMode */
    /** @} group_constants */
#endif

/* Digital Port Constants */
#define Clock_In_25KHz_MASK               Clock_In_25KHz__MASK
#define Clock_In_25KHz_SHIFT              Clock_In_25KHz__SHIFT
#define Clock_In_25KHz_WIDTH              1u

/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in Clock_In_25KHz_SetInterruptMode() function.
     *  @{
     */
        #define Clock_In_25KHz_INTR_NONE      ((uint16)(0x0000u)) /**< \brief Disabled             */
        #define Clock_In_25KHz_INTR_RISING    ((uint16)(0x5555u)) /**< \brief Rising edge trigger  */
        #define Clock_In_25KHz_INTR_FALLING   ((uint16)(0xaaaau)) /**< \brief Falling edge trigger */
        #define Clock_In_25KHz_INTR_BOTH      ((uint16)(0xffffu)) /**< \brief Both edge trigger    */
    /** @} intrMode */
/** @} group_constants */

/* SIO LPM definition */
#if defined(Clock_In_25KHz__SIO)
    #define Clock_In_25KHz_SIO_LPM_MASK       (0x03u)
#endif

/* USBIO definitions */
#if !defined(Clock_In_25KHz__PC) && (CY_PSOC4_4200L)
    #define Clock_In_25KHz_USBIO_ENABLE               ((uint32)0x80000000u)
    #define Clock_In_25KHz_USBIO_DISABLE              ((uint32)(~Clock_In_25KHz_USBIO_ENABLE))
    #define Clock_In_25KHz_USBIO_SUSPEND_SHIFT        CYFLD_USBDEVv2_USB_SUSPEND__OFFSET
    #define Clock_In_25KHz_USBIO_SUSPEND_DEL_SHIFT    CYFLD_USBDEVv2_USB_SUSPEND_DEL__OFFSET
    #define Clock_In_25KHz_USBIO_ENTER_SLEEP          ((uint32)((1u << Clock_In_25KHz_USBIO_SUSPEND_SHIFT) \
                                                        | (1u << Clock_In_25KHz_USBIO_SUSPEND_DEL_SHIFT)))
    #define Clock_In_25KHz_USBIO_EXIT_SLEEP_PH1       ((uint32)~((uint32)(1u << Clock_In_25KHz_USBIO_SUSPEND_SHIFT)))
    #define Clock_In_25KHz_USBIO_EXIT_SLEEP_PH2       ((uint32)~((uint32)(1u << Clock_In_25KHz_USBIO_SUSPEND_DEL_SHIFT)))
    #define Clock_In_25KHz_USBIO_CR1_OFF              ((uint32)0xfffffffeu)
#endif


/***************************************
*             Registers        
***************************************/
/* Main Port Registers */
#if defined(Clock_In_25KHz__PC)
    /* Port Configuration */
    #define Clock_In_25KHz_PC                 (* (reg32 *) Clock_In_25KHz__PC)
#endif
/* Pin State */
#define Clock_In_25KHz_PS                     (* (reg32 *) Clock_In_25KHz__PS)
/* Data Register */
#define Clock_In_25KHz_DR                     (* (reg32 *) Clock_In_25KHz__DR)
/* Input Buffer Disable Override */
#define Clock_In_25KHz_INP_DIS                (* (reg32 *) Clock_In_25KHz__PC2)

/* Interrupt configuration Registers */
#define Clock_In_25KHz_INTCFG                 (* (reg32 *) Clock_In_25KHz__INTCFG)
#define Clock_In_25KHz_INTSTAT                (* (reg32 *) Clock_In_25KHz__INTSTAT)

/* "Interrupt cause" register for Combined Port Interrupt (AllPortInt) in GSRef component */
#if defined (CYREG_GPIO_INTR_CAUSE)
    #define Clock_In_25KHz_INTR_CAUSE         (* (reg32 *) CYREG_GPIO_INTR_CAUSE)
#endif

/* SIO register */
#if defined(Clock_In_25KHz__SIO)
    #define Clock_In_25KHz_SIO_REG            (* (reg32 *) Clock_In_25KHz__SIO)
#endif /* (Clock_In_25KHz__SIO_CFG) */

/* USBIO registers */
#if !defined(Clock_In_25KHz__PC) && (CY_PSOC4_4200L)
    #define Clock_In_25KHz_USB_POWER_REG       (* (reg32 *) CYREG_USBDEVv2_USB_POWER_CTRL)
    #define Clock_In_25KHz_CR1_REG             (* (reg32 *) CYREG_USBDEVv2_CR1)
    #define Clock_In_25KHz_USBIO_CTRL_REG      (* (reg32 *) CYREG_USBDEVv2_USB_USBIO_CTRL)
#endif    
    
    
/***************************************
* The following code is DEPRECATED and 
* must not be used in new designs.
***************************************/
/**
* \addtogroup group_deprecated
* @{
*/
#define Clock_In_25KHz_DRIVE_MODE_SHIFT       (0x00u)
#define Clock_In_25KHz_DRIVE_MODE_MASK        (0x07u << Clock_In_25KHz_DRIVE_MODE_SHIFT)
/** @} deprecated */

#endif /* End Pins Clock_In_25KHz_H */


/* [] END OF FILE */
