/*******************************************************************************
* File Name: Counter1.h
* Version 2.10
*
* Description:
*  This file provides constants and parameter values for the Counter1
*  component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_TCPWM_Counter1_H)
#define CY_TCPWM_Counter1_H


#include "CyLib.h"
#include "cytypes.h"
#include "cyfitter.h"


/*******************************************************************************
* Internal Type defines
*******************************************************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} Counter1_BACKUP_STRUCT;


/*******************************************************************************
* Variables
*******************************************************************************/
extern uint8  Counter1_initVar;


/***************************************
*   Conditional Compilation Parameters
****************************************/

#define Counter1_CY_TCPWM_V2                    (CYIPBLOCK_m0s8tcpwm_VERSION == 2u)
#define Counter1_CY_TCPWM_4000                  (CY_PSOC4_4000)

/* TCPWM Configuration */
#define Counter1_CONFIG                         (7lu)

/* Quad Mode */
/* Parameters */
#define Counter1_QUAD_ENCODING_MODES            (0lu)
#define Counter1_QUAD_AUTO_START                (1lu)

/* Signal modes */
#define Counter1_QUAD_INDEX_SIGNAL_MODE         (0lu)
#define Counter1_QUAD_PHIA_SIGNAL_MODE          (3lu)
#define Counter1_QUAD_PHIB_SIGNAL_MODE          (3lu)
#define Counter1_QUAD_STOP_SIGNAL_MODE          (0lu)

/* Signal present */
#define Counter1_QUAD_INDEX_SIGNAL_PRESENT      (0lu)
#define Counter1_QUAD_STOP_SIGNAL_PRESENT       (0lu)

/* Interrupt Mask */
#define Counter1_QUAD_INTERRUPT_MASK            (1lu)

/* Timer/Counter Mode */
/* Parameters */
#define Counter1_TC_RUN_MODE                    (0lu)
#define Counter1_TC_COUNTER_MODE                (0lu)
#define Counter1_TC_COMP_CAP_MODE               (2lu)
#define Counter1_TC_PRESCALER                   (0lu)

/* Signal modes */
#define Counter1_TC_RELOAD_SIGNAL_MODE          (0lu)
#define Counter1_TC_COUNT_SIGNAL_MODE           (3lu)
#define Counter1_TC_START_SIGNAL_MODE           (0lu)
#define Counter1_TC_STOP_SIGNAL_MODE            (0lu)
#define Counter1_TC_CAPTURE_SIGNAL_MODE         (0lu)

/* Signal present */
#define Counter1_TC_RELOAD_SIGNAL_PRESENT       (0lu)
#define Counter1_TC_COUNT_SIGNAL_PRESENT        (0lu)
#define Counter1_TC_START_SIGNAL_PRESENT        (0lu)
#define Counter1_TC_STOP_SIGNAL_PRESENT         (0lu)
#define Counter1_TC_CAPTURE_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define Counter1_TC_INTERRUPT_MASK              (1lu)

/* PWM Mode */
/* Parameters */
#define Counter1_PWM_KILL_EVENT                 (0lu)
#define Counter1_PWM_STOP_EVENT                 (0lu)
#define Counter1_PWM_MODE                       (4lu)
#define Counter1_PWM_OUT_N_INVERT               (0lu)
#define Counter1_PWM_OUT_INVERT                 (0lu)
#define Counter1_PWM_ALIGN                      (0lu)
#define Counter1_PWM_RUN_MODE                   (0lu)
#define Counter1_PWM_DEAD_TIME_CYCLE            (0lu)
#define Counter1_PWM_PRESCALER                  (0lu)

/* Signal modes */
#define Counter1_PWM_RELOAD_SIGNAL_MODE         (0lu)
#define Counter1_PWM_COUNT_SIGNAL_MODE          (0lu)
#define Counter1_PWM_START_SIGNAL_MODE          (0lu)
#define Counter1_PWM_STOP_SIGNAL_MODE           (0lu)
#define Counter1_PWM_SWITCH_SIGNAL_MODE         (0lu)

/* Signal present */
#define Counter1_PWM_RELOAD_SIGNAL_PRESENT      (0lu)
#define Counter1_PWM_COUNT_SIGNAL_PRESENT       (1lu)
#define Counter1_PWM_START_SIGNAL_PRESENT       (1lu)
#define Counter1_PWM_STOP_SIGNAL_PRESENT        (1lu)
#define Counter1_PWM_SWITCH_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define Counter1_PWM_INTERRUPT_MASK             (0lu)


/***************************************
*    Initial Parameter Constants
***************************************/

/* Timer/Counter Mode */
#define Counter1_TC_PERIOD_VALUE                (65535lu)
#define Counter1_TC_COMPARE_VALUE               (65535lu)
#define Counter1_TC_COMPARE_BUF_VALUE           (65535lu)
#define Counter1_TC_COMPARE_SWAP                (0lu)

/* PWM Mode */
#define Counter1_PWM_PERIOD_VALUE               (10000lu)
#define Counter1_PWM_PERIOD_BUF_VALUE           (65535lu)
#define Counter1_PWM_PERIOD_SWAP                (0lu)
#define Counter1_PWM_COMPARE_VALUE              (5000lu)
#define Counter1_PWM_COMPARE_BUF_VALUE          (65535lu)
#define Counter1_PWM_COMPARE_SWAP               (0lu)


/***************************************
*    Enumerated Types and Parameters
***************************************/

#define Counter1__LEFT 0
#define Counter1__RIGHT 1
#define Counter1__CENTER 2
#define Counter1__ASYMMETRIC 3

#define Counter1__X1 0
#define Counter1__X2 1
#define Counter1__X4 2

#define Counter1__PWM 4
#define Counter1__PWM_DT 5
#define Counter1__PWM_PR 6

#define Counter1__INVERSE 1
#define Counter1__DIRECT 0

#define Counter1__CAPTURE 2
#define Counter1__COMPARE 0

#define Counter1__TRIG_LEVEL 3
#define Counter1__TRIG_RISING 0
#define Counter1__TRIG_FALLING 1
#define Counter1__TRIG_BOTH 2

#define Counter1__INTR_MASK_TC 1
#define Counter1__INTR_MASK_CC_MATCH 2
#define Counter1__INTR_MASK_NONE 0
#define Counter1__INTR_MASK_TC_CC 3

#define Counter1__UNCONFIG 8
#define Counter1__TIMER 1
#define Counter1__QUAD 3
#define Counter1__PWM_SEL 7

#define Counter1__COUNT_UP 0
#define Counter1__COUNT_DOWN 1
#define Counter1__COUNT_UPDOWN0 2
#define Counter1__COUNT_UPDOWN1 3


/* Prescaler */
#define Counter1_PRESCALE_DIVBY1                ((uint32)(0u << Counter1_PRESCALER_SHIFT))
#define Counter1_PRESCALE_DIVBY2                ((uint32)(1u << Counter1_PRESCALER_SHIFT))
#define Counter1_PRESCALE_DIVBY4                ((uint32)(2u << Counter1_PRESCALER_SHIFT))
#define Counter1_PRESCALE_DIVBY8                ((uint32)(3u << Counter1_PRESCALER_SHIFT))
#define Counter1_PRESCALE_DIVBY16               ((uint32)(4u << Counter1_PRESCALER_SHIFT))
#define Counter1_PRESCALE_DIVBY32               ((uint32)(5u << Counter1_PRESCALER_SHIFT))
#define Counter1_PRESCALE_DIVBY64               ((uint32)(6u << Counter1_PRESCALER_SHIFT))
#define Counter1_PRESCALE_DIVBY128              ((uint32)(7u << Counter1_PRESCALER_SHIFT))

/* TCPWM set modes */
#define Counter1_MODE_TIMER_COMPARE             ((uint32)(Counter1__COMPARE         <<  \
                                                                  Counter1_MODE_SHIFT))
#define Counter1_MODE_TIMER_CAPTURE             ((uint32)(Counter1__CAPTURE         <<  \
                                                                  Counter1_MODE_SHIFT))
#define Counter1_MODE_QUAD                      ((uint32)(Counter1__QUAD            <<  \
                                                                  Counter1_MODE_SHIFT))
#define Counter1_MODE_PWM                       ((uint32)(Counter1__PWM             <<  \
                                                                  Counter1_MODE_SHIFT))
#define Counter1_MODE_PWM_DT                    ((uint32)(Counter1__PWM_DT          <<  \
                                                                  Counter1_MODE_SHIFT))
#define Counter1_MODE_PWM_PR                    ((uint32)(Counter1__PWM_PR          <<  \
                                                                  Counter1_MODE_SHIFT))

/* Quad Modes */
#define Counter1_MODE_X1                        ((uint32)(Counter1__X1              <<  \
                                                                  Counter1_QUAD_MODE_SHIFT))
#define Counter1_MODE_X2                        ((uint32)(Counter1__X2              <<  \
                                                                  Counter1_QUAD_MODE_SHIFT))
#define Counter1_MODE_X4                        ((uint32)(Counter1__X4              <<  \
                                                                  Counter1_QUAD_MODE_SHIFT))

/* Counter modes */
#define Counter1_COUNT_UP                       ((uint32)(Counter1__COUNT_UP        <<  \
                                                                  Counter1_UPDOWN_SHIFT))
#define Counter1_COUNT_DOWN                     ((uint32)(Counter1__COUNT_DOWN      <<  \
                                                                  Counter1_UPDOWN_SHIFT))
#define Counter1_COUNT_UPDOWN0                  ((uint32)(Counter1__COUNT_UPDOWN0   <<  \
                                                                  Counter1_UPDOWN_SHIFT))
#define Counter1_COUNT_UPDOWN1                  ((uint32)(Counter1__COUNT_UPDOWN1   <<  \
                                                                  Counter1_UPDOWN_SHIFT))

/* PWM output invert */
#define Counter1_INVERT_LINE                    ((uint32)(Counter1__INVERSE         <<  \
                                                                  Counter1_INV_OUT_SHIFT))
#define Counter1_INVERT_LINE_N                  ((uint32)(Counter1__INVERSE         <<  \
                                                                  Counter1_INV_COMPL_OUT_SHIFT))

/* Trigger modes */
#define Counter1_TRIG_RISING                    ((uint32)Counter1__TRIG_RISING)
#define Counter1_TRIG_FALLING                   ((uint32)Counter1__TRIG_FALLING)
#define Counter1_TRIG_BOTH                      ((uint32)Counter1__TRIG_BOTH)
#define Counter1_TRIG_LEVEL                     ((uint32)Counter1__TRIG_LEVEL)

/* Interrupt mask */
#define Counter1_INTR_MASK_TC                   ((uint32)Counter1__INTR_MASK_TC)
#define Counter1_INTR_MASK_CC_MATCH             ((uint32)Counter1__INTR_MASK_CC_MATCH)

/* PWM Output Controls */
#define Counter1_CC_MATCH_SET                   (0x00u)
#define Counter1_CC_MATCH_CLEAR                 (0x01u)
#define Counter1_CC_MATCH_INVERT                (0x02u)
#define Counter1_CC_MATCH_NO_CHANGE             (0x03u)
#define Counter1_OVERLOW_SET                    (0x00u)
#define Counter1_OVERLOW_CLEAR                  (0x04u)
#define Counter1_OVERLOW_INVERT                 (0x08u)
#define Counter1_OVERLOW_NO_CHANGE              (0x0Cu)
#define Counter1_UNDERFLOW_SET                  (0x00u)
#define Counter1_UNDERFLOW_CLEAR                (0x10u)
#define Counter1_UNDERFLOW_INVERT               (0x20u)
#define Counter1_UNDERFLOW_NO_CHANGE            (0x30u)

/* PWM Align */
#define Counter1_PWM_MODE_LEFT                  (Counter1_CC_MATCH_CLEAR        |   \
                                                         Counter1_OVERLOW_SET           |   \
                                                         Counter1_UNDERFLOW_NO_CHANGE)
#define Counter1_PWM_MODE_RIGHT                 (Counter1_CC_MATCH_SET          |   \
                                                         Counter1_OVERLOW_NO_CHANGE     |   \
                                                         Counter1_UNDERFLOW_CLEAR)
#define Counter1_PWM_MODE_ASYM                  (Counter1_CC_MATCH_INVERT       |   \
                                                         Counter1_OVERLOW_SET           |   \
                                                         Counter1_UNDERFLOW_CLEAR)

#if (Counter1_CY_TCPWM_V2)
    #if(Counter1_CY_TCPWM_4000)
        #define Counter1_PWM_MODE_CENTER                (Counter1_CC_MATCH_INVERT       |   \
                                                                 Counter1_OVERLOW_NO_CHANGE     |   \
                                                                 Counter1_UNDERFLOW_CLEAR)
    #else
        #define Counter1_PWM_MODE_CENTER                (Counter1_CC_MATCH_INVERT       |   \
                                                                 Counter1_OVERLOW_SET           |   \
                                                                 Counter1_UNDERFLOW_CLEAR)
    #endif /* (Counter1_CY_TCPWM_4000) */
#else
    #define Counter1_PWM_MODE_CENTER                (Counter1_CC_MATCH_INVERT       |   \
                                                             Counter1_OVERLOW_NO_CHANGE     |   \
                                                             Counter1_UNDERFLOW_CLEAR)
#endif /* (Counter1_CY_TCPWM_NEW) */

/* Command operations without condition */
#define Counter1_CMD_CAPTURE                    (0u)
#define Counter1_CMD_RELOAD                     (8u)
#define Counter1_CMD_STOP                       (16u)
#define Counter1_CMD_START                      (24u)

/* Status */
#define Counter1_STATUS_DOWN                    (1u)
#define Counter1_STATUS_RUNNING                 (2u)


/***************************************
*        Function Prototypes
****************************************/

void   Counter1_Init(void);
void   Counter1_Enable(void);
void   Counter1_Start(void);
void   Counter1_Stop(void);

void   Counter1_SetMode(uint32 mode);
void   Counter1_SetCounterMode(uint32 counterMode);
void   Counter1_SetPWMMode(uint32 modeMask);
void   Counter1_SetQDMode(uint32 qdMode);

void   Counter1_SetPrescaler(uint32 prescaler);
void   Counter1_TriggerCommand(uint32 mask, uint32 command);
void   Counter1_SetOneShot(uint32 oneShotEnable);
uint32 Counter1_ReadStatus(void);

void   Counter1_SetPWMSyncKill(uint32 syncKillEnable);
void   Counter1_SetPWMStopOnKill(uint32 stopOnKillEnable);
void   Counter1_SetPWMDeadTime(uint32 deadTime);
void   Counter1_SetPWMInvert(uint32 mask);

void   Counter1_SetInterruptMode(uint32 interruptMask);
uint32 Counter1_GetInterruptSourceMasked(void);
uint32 Counter1_GetInterruptSource(void);
void   Counter1_ClearInterrupt(uint32 interruptMask);
void   Counter1_SetInterrupt(uint32 interruptMask);

void   Counter1_WriteCounter(uint32 count);
uint32 Counter1_ReadCounter(void);

uint32 Counter1_ReadCapture(void);
uint32 Counter1_ReadCaptureBuf(void);

void   Counter1_WritePeriod(uint32 period);
uint32 Counter1_ReadPeriod(void);
void   Counter1_WritePeriodBuf(uint32 periodBuf);
uint32 Counter1_ReadPeriodBuf(void);

void   Counter1_WriteCompare(uint32 compare);
uint32 Counter1_ReadCompare(void);
void   Counter1_WriteCompareBuf(uint32 compareBuf);
uint32 Counter1_ReadCompareBuf(void);

void   Counter1_SetPeriodSwap(uint32 swapEnable);
void   Counter1_SetCompareSwap(uint32 swapEnable);

void   Counter1_SetCaptureMode(uint32 triggerMode);
void   Counter1_SetReloadMode(uint32 triggerMode);
void   Counter1_SetStartMode(uint32 triggerMode);
void   Counter1_SetStopMode(uint32 triggerMode);
void   Counter1_SetCountMode(uint32 triggerMode);

void   Counter1_SaveConfig(void);
void   Counter1_RestoreConfig(void);
void   Counter1_Sleep(void);
void   Counter1_Wakeup(void);


/***************************************
*             Registers
***************************************/

#define Counter1_BLOCK_CONTROL_REG              (*(reg32 *) Counter1_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define Counter1_BLOCK_CONTROL_PTR              ( (reg32 *) Counter1_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define Counter1_COMMAND_REG                    (*(reg32 *) Counter1_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define Counter1_COMMAND_PTR                    ( (reg32 *) Counter1_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define Counter1_INTRRUPT_CAUSE_REG             (*(reg32 *) Counter1_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define Counter1_INTRRUPT_CAUSE_PTR             ( (reg32 *) Counter1_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define Counter1_CONTROL_REG                    (*(reg32 *) Counter1_cy_m0s8_tcpwm_1__CTRL )
#define Counter1_CONTROL_PTR                    ( (reg32 *) Counter1_cy_m0s8_tcpwm_1__CTRL )
#define Counter1_STATUS_REG                     (*(reg32 *) Counter1_cy_m0s8_tcpwm_1__STATUS )
#define Counter1_STATUS_PTR                     ( (reg32 *) Counter1_cy_m0s8_tcpwm_1__STATUS )
#define Counter1_COUNTER_REG                    (*(reg32 *) Counter1_cy_m0s8_tcpwm_1__COUNTER )
#define Counter1_COUNTER_PTR                    ( (reg32 *) Counter1_cy_m0s8_tcpwm_1__COUNTER )
#define Counter1_COMP_CAP_REG                   (*(reg32 *) Counter1_cy_m0s8_tcpwm_1__CC )
#define Counter1_COMP_CAP_PTR                   ( (reg32 *) Counter1_cy_m0s8_tcpwm_1__CC )
#define Counter1_COMP_CAP_BUF_REG               (*(reg32 *) Counter1_cy_m0s8_tcpwm_1__CC_BUFF )
#define Counter1_COMP_CAP_BUF_PTR               ( (reg32 *) Counter1_cy_m0s8_tcpwm_1__CC_BUFF )
#define Counter1_PERIOD_REG                     (*(reg32 *) Counter1_cy_m0s8_tcpwm_1__PERIOD )
#define Counter1_PERIOD_PTR                     ( (reg32 *) Counter1_cy_m0s8_tcpwm_1__PERIOD )
#define Counter1_PERIOD_BUF_REG                 (*(reg32 *) Counter1_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define Counter1_PERIOD_BUF_PTR                 ( (reg32 *) Counter1_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define Counter1_TRIG_CONTROL0_REG              (*(reg32 *) Counter1_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define Counter1_TRIG_CONTROL0_PTR              ( (reg32 *) Counter1_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define Counter1_TRIG_CONTROL1_REG              (*(reg32 *) Counter1_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define Counter1_TRIG_CONTROL1_PTR              ( (reg32 *) Counter1_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define Counter1_TRIG_CONTROL2_REG              (*(reg32 *) Counter1_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define Counter1_TRIG_CONTROL2_PTR              ( (reg32 *) Counter1_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define Counter1_INTERRUPT_REQ_REG              (*(reg32 *) Counter1_cy_m0s8_tcpwm_1__INTR )
#define Counter1_INTERRUPT_REQ_PTR              ( (reg32 *) Counter1_cy_m0s8_tcpwm_1__INTR )
#define Counter1_INTERRUPT_SET_REG              (*(reg32 *) Counter1_cy_m0s8_tcpwm_1__INTR_SET )
#define Counter1_INTERRUPT_SET_PTR              ( (reg32 *) Counter1_cy_m0s8_tcpwm_1__INTR_SET )
#define Counter1_INTERRUPT_MASK_REG             (*(reg32 *) Counter1_cy_m0s8_tcpwm_1__INTR_MASK )
#define Counter1_INTERRUPT_MASK_PTR             ( (reg32 *) Counter1_cy_m0s8_tcpwm_1__INTR_MASK )
#define Counter1_INTERRUPT_MASKED_REG           (*(reg32 *) Counter1_cy_m0s8_tcpwm_1__INTR_MASKED )
#define Counter1_INTERRUPT_MASKED_PTR           ( (reg32 *) Counter1_cy_m0s8_tcpwm_1__INTR_MASKED )


/***************************************
*       Registers Constants
***************************************/

/* Mask */
#define Counter1_MASK                           ((uint32)Counter1_cy_m0s8_tcpwm_1__TCPWM_CTRL_MASK)

/* Shift constants for control register */
#define Counter1_RELOAD_CC_SHIFT                (0u)
#define Counter1_RELOAD_PERIOD_SHIFT            (1u)
#define Counter1_PWM_SYNC_KILL_SHIFT            (2u)
#define Counter1_PWM_STOP_KILL_SHIFT            (3u)
#define Counter1_PRESCALER_SHIFT                (8u)
#define Counter1_UPDOWN_SHIFT                   (16u)
#define Counter1_ONESHOT_SHIFT                  (18u)
#define Counter1_QUAD_MODE_SHIFT                (20u)
#define Counter1_INV_OUT_SHIFT                  (20u)
#define Counter1_INV_COMPL_OUT_SHIFT            (21u)
#define Counter1_MODE_SHIFT                     (24u)

/* Mask constants for control register */
#define Counter1_RELOAD_CC_MASK                 ((uint32)(Counter1_1BIT_MASK        <<  \
                                                                            Counter1_RELOAD_CC_SHIFT))
#define Counter1_RELOAD_PERIOD_MASK             ((uint32)(Counter1_1BIT_MASK        <<  \
                                                                            Counter1_RELOAD_PERIOD_SHIFT))
#define Counter1_PWM_SYNC_KILL_MASK             ((uint32)(Counter1_1BIT_MASK        <<  \
                                                                            Counter1_PWM_SYNC_KILL_SHIFT))
#define Counter1_PWM_STOP_KILL_MASK             ((uint32)(Counter1_1BIT_MASK        <<  \
                                                                            Counter1_PWM_STOP_KILL_SHIFT))
#define Counter1_PRESCALER_MASK                 ((uint32)(Counter1_8BIT_MASK        <<  \
                                                                            Counter1_PRESCALER_SHIFT))
#define Counter1_UPDOWN_MASK                    ((uint32)(Counter1_2BIT_MASK        <<  \
                                                                            Counter1_UPDOWN_SHIFT))
#define Counter1_ONESHOT_MASK                   ((uint32)(Counter1_1BIT_MASK        <<  \
                                                                            Counter1_ONESHOT_SHIFT))
#define Counter1_QUAD_MODE_MASK                 ((uint32)(Counter1_3BIT_MASK        <<  \
                                                                            Counter1_QUAD_MODE_SHIFT))
#define Counter1_INV_OUT_MASK                   ((uint32)(Counter1_2BIT_MASK        <<  \
                                                                            Counter1_INV_OUT_SHIFT))
#define Counter1_MODE_MASK                      ((uint32)(Counter1_3BIT_MASK        <<  \
                                                                            Counter1_MODE_SHIFT))

/* Shift constants for trigger control register 1 */
#define Counter1_CAPTURE_SHIFT                  (0u)
#define Counter1_COUNT_SHIFT                    (2u)
#define Counter1_RELOAD_SHIFT                   (4u)
#define Counter1_STOP_SHIFT                     (6u)
#define Counter1_START_SHIFT                    (8u)

/* Mask constants for trigger control register 1 */
#define Counter1_CAPTURE_MASK                   ((uint32)(Counter1_2BIT_MASK        <<  \
                                                                  Counter1_CAPTURE_SHIFT))
#define Counter1_COUNT_MASK                     ((uint32)(Counter1_2BIT_MASK        <<  \
                                                                  Counter1_COUNT_SHIFT))
#define Counter1_RELOAD_MASK                    ((uint32)(Counter1_2BIT_MASK        <<  \
                                                                  Counter1_RELOAD_SHIFT))
#define Counter1_STOP_MASK                      ((uint32)(Counter1_2BIT_MASK        <<  \
                                                                  Counter1_STOP_SHIFT))
#define Counter1_START_MASK                     ((uint32)(Counter1_2BIT_MASK        <<  \
                                                                  Counter1_START_SHIFT))

/* MASK */
#define Counter1_1BIT_MASK                      ((uint32)0x01u)
#define Counter1_2BIT_MASK                      ((uint32)0x03u)
#define Counter1_3BIT_MASK                      ((uint32)0x07u)
#define Counter1_6BIT_MASK                      ((uint32)0x3Fu)
#define Counter1_8BIT_MASK                      ((uint32)0xFFu)
#define Counter1_16BIT_MASK                     ((uint32)0xFFFFu)

/* Shift constant for status register */
#define Counter1_RUNNING_STATUS_SHIFT           (30u)


/***************************************
*    Initial Constants
***************************************/

#define Counter1_CTRL_QUAD_BASE_CONFIG                                                          \
        (((uint32)(Counter1_QUAD_ENCODING_MODES     << Counter1_QUAD_MODE_SHIFT))       |\
         ((uint32)(Counter1_CONFIG                  << Counter1_MODE_SHIFT)))

#define Counter1_CTRL_PWM_BASE_CONFIG                                                           \
        (((uint32)(Counter1_PWM_STOP_EVENT          << Counter1_PWM_STOP_KILL_SHIFT))   |\
         ((uint32)(Counter1_PWM_OUT_INVERT          << Counter1_INV_OUT_SHIFT))         |\
         ((uint32)(Counter1_PWM_OUT_N_INVERT        << Counter1_INV_COMPL_OUT_SHIFT))   |\
         ((uint32)(Counter1_PWM_MODE                << Counter1_MODE_SHIFT)))

#define Counter1_CTRL_PWM_RUN_MODE                                                              \
            ((uint32)(Counter1_PWM_RUN_MODE         << Counter1_ONESHOT_SHIFT))
            
#define Counter1_CTRL_PWM_ALIGN                                                                 \
            ((uint32)(Counter1_PWM_ALIGN            << Counter1_UPDOWN_SHIFT))

#define Counter1_CTRL_PWM_KILL_EVENT                                                            \
             ((uint32)(Counter1_PWM_KILL_EVENT      << Counter1_PWM_SYNC_KILL_SHIFT))

#define Counter1_CTRL_PWM_DEAD_TIME_CYCLE                                                       \
            ((uint32)(Counter1_PWM_DEAD_TIME_CYCLE  << Counter1_PRESCALER_SHIFT))

#define Counter1_CTRL_PWM_PRESCALER                                                             \
            ((uint32)(Counter1_PWM_PRESCALER        << Counter1_PRESCALER_SHIFT))

#define Counter1_CTRL_TIMER_BASE_CONFIG                                                         \
        (((uint32)(Counter1_TC_PRESCALER            << Counter1_PRESCALER_SHIFT))       |\
         ((uint32)(Counter1_TC_COUNTER_MODE         << Counter1_UPDOWN_SHIFT))          |\
         ((uint32)(Counter1_TC_RUN_MODE             << Counter1_ONESHOT_SHIFT))         |\
         ((uint32)(Counter1_TC_COMP_CAP_MODE        << Counter1_MODE_SHIFT)))
        
#define Counter1_QUAD_SIGNALS_MODES                                                             \
        (((uint32)(Counter1_QUAD_PHIA_SIGNAL_MODE   << Counter1_COUNT_SHIFT))           |\
         ((uint32)(Counter1_QUAD_INDEX_SIGNAL_MODE  << Counter1_RELOAD_SHIFT))          |\
         ((uint32)(Counter1_QUAD_STOP_SIGNAL_MODE   << Counter1_STOP_SHIFT))            |\
         ((uint32)(Counter1_QUAD_PHIB_SIGNAL_MODE   << Counter1_START_SHIFT)))

#define Counter1_PWM_SIGNALS_MODES                                                              \
        (((uint32)(Counter1_PWM_SWITCH_SIGNAL_MODE  << Counter1_CAPTURE_SHIFT))         |\
         ((uint32)(Counter1_PWM_COUNT_SIGNAL_MODE   << Counter1_COUNT_SHIFT))           |\
         ((uint32)(Counter1_PWM_RELOAD_SIGNAL_MODE  << Counter1_RELOAD_SHIFT))          |\
         ((uint32)(Counter1_PWM_STOP_SIGNAL_MODE    << Counter1_STOP_SHIFT))            |\
         ((uint32)(Counter1_PWM_START_SIGNAL_MODE   << Counter1_START_SHIFT)))

#define Counter1_TIMER_SIGNALS_MODES                                                            \
        (((uint32)(Counter1_TC_CAPTURE_SIGNAL_MODE  << Counter1_CAPTURE_SHIFT))         |\
         ((uint32)(Counter1_TC_COUNT_SIGNAL_MODE    << Counter1_COUNT_SHIFT))           |\
         ((uint32)(Counter1_TC_RELOAD_SIGNAL_MODE   << Counter1_RELOAD_SHIFT))          |\
         ((uint32)(Counter1_TC_STOP_SIGNAL_MODE     << Counter1_STOP_SHIFT))            |\
         ((uint32)(Counter1_TC_START_SIGNAL_MODE    << Counter1_START_SHIFT)))
        
#define Counter1_TIMER_UPDOWN_CNT_USED                                                          \
                ((Counter1__COUNT_UPDOWN0 == Counter1_TC_COUNTER_MODE)                  ||\
                 (Counter1__COUNT_UPDOWN1 == Counter1_TC_COUNTER_MODE))

#define Counter1_PWM_UPDOWN_CNT_USED                                                            \
                ((Counter1__CENTER == Counter1_PWM_ALIGN)                               ||\
                 (Counter1__ASYMMETRIC == Counter1_PWM_ALIGN))               
        
#define Counter1_PWM_PR_INIT_VALUE              (1u)
#define Counter1_QUAD_PERIOD_INIT_VALUE         (0x8000u)



#endif /* End CY_TCPWM_Counter1_H */

/* [] END OF FILE */
