/*******************************************************************************
* File Name: Counter2.c
* Version 2.10
*
* Description:
*  This file provides the source code to the API for the Counter2
*  component
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "Counter2.h"

uint8 Counter2_initVar = 0u;


/*******************************************************************************
* Function Name: Counter2_Init
********************************************************************************
*
* Summary:
*  Initialize/Restore default Counter2 configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_Init(void)
{

    /* Set values from customizer to CTRL */
    #if (Counter2__QUAD == Counter2_CONFIG)
        Counter2_CONTROL_REG = Counter2_CTRL_QUAD_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        Counter2_TRIG_CONTROL1_REG  = Counter2_QUAD_SIGNALS_MODES;

        /* Set values from customizer to INTR */
        Counter2_SetInterruptMode(Counter2_QUAD_INTERRUPT_MASK);
        
         /* Set other values */
        Counter2_SetCounterMode(Counter2_COUNT_DOWN);
        Counter2_WritePeriod(Counter2_QUAD_PERIOD_INIT_VALUE);
        Counter2_WriteCounter(Counter2_QUAD_PERIOD_INIT_VALUE);
    #endif  /* (Counter2__QUAD == Counter2_CONFIG) */

    #if (Counter2__TIMER == Counter2_CONFIG)
        Counter2_CONTROL_REG = Counter2_CTRL_TIMER_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        Counter2_TRIG_CONTROL1_REG  = Counter2_TIMER_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        Counter2_SetInterruptMode(Counter2_TC_INTERRUPT_MASK);
        
        /* Set other values from customizer */
        Counter2_WritePeriod(Counter2_TC_PERIOD_VALUE );

        #if (Counter2__COMPARE == Counter2_TC_COMP_CAP_MODE)
            Counter2_WriteCompare(Counter2_TC_COMPARE_VALUE);

            #if (1u == Counter2_TC_COMPARE_SWAP)
                Counter2_SetCompareSwap(1u);
                Counter2_WriteCompareBuf(Counter2_TC_COMPARE_BUF_VALUE);
            #endif  /* (1u == Counter2_TC_COMPARE_SWAP) */
        #endif  /* (Counter2__COMPARE == Counter2_TC_COMP_CAP_MODE) */

        /* Initialize counter value */
        #if (Counter2_CY_TCPWM_V2 && Counter2_TIMER_UPDOWN_CNT_USED && !Counter2_CY_TCPWM_4000)
            Counter2_WriteCounter(1u);
        #elif(Counter2__COUNT_DOWN == Counter2_TC_COUNTER_MODE)
            Counter2_WriteCounter(Counter2_TC_PERIOD_VALUE);
        #else
            Counter2_WriteCounter(0u);
        #endif /* (Counter2_CY_TCPWM_V2 && Counter2_TIMER_UPDOWN_CNT_USED && !Counter2_CY_TCPWM_4000) */
    #endif  /* (Counter2__TIMER == Counter2_CONFIG) */

    #if (Counter2__PWM_SEL == Counter2_CONFIG)
        Counter2_CONTROL_REG = Counter2_CTRL_PWM_BASE_CONFIG;

        #if (Counter2__PWM_PR == Counter2_PWM_MODE)
            Counter2_CONTROL_REG |= Counter2_CTRL_PWM_RUN_MODE;
            Counter2_WriteCounter(Counter2_PWM_PR_INIT_VALUE);
        #else
            Counter2_CONTROL_REG |= Counter2_CTRL_PWM_ALIGN | Counter2_CTRL_PWM_KILL_EVENT;
            
            /* Initialize counter value */
            #if (Counter2_CY_TCPWM_V2 && Counter2_PWM_UPDOWN_CNT_USED && !Counter2_CY_TCPWM_4000)
                Counter2_WriteCounter(1u);
            #elif (Counter2__RIGHT == Counter2_PWM_ALIGN)
                Counter2_WriteCounter(Counter2_PWM_PERIOD_VALUE);
            #else 
                Counter2_WriteCounter(0u);
            #endif  /* (Counter2_CY_TCPWM_V2 && Counter2_PWM_UPDOWN_CNT_USED && !Counter2_CY_TCPWM_4000) */
        #endif  /* (Counter2__PWM_PR == Counter2_PWM_MODE) */

        #if (Counter2__PWM_DT == Counter2_PWM_MODE)
            Counter2_CONTROL_REG |= Counter2_CTRL_PWM_DEAD_TIME_CYCLE;
        #endif  /* (Counter2__PWM_DT == Counter2_PWM_MODE) */

        #if (Counter2__PWM == Counter2_PWM_MODE)
            Counter2_CONTROL_REG |= Counter2_CTRL_PWM_PRESCALER;
        #endif  /* (Counter2__PWM == Counter2_PWM_MODE) */

        /* Set values from customizer to CTRL1 */
        Counter2_TRIG_CONTROL1_REG  = Counter2_PWM_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        Counter2_SetInterruptMode(Counter2_PWM_INTERRUPT_MASK);

        /* Set values from customizer to CTRL2 */
        #if (Counter2__PWM_PR == Counter2_PWM_MODE)
            Counter2_TRIG_CONTROL2_REG =
                    (Counter2_CC_MATCH_NO_CHANGE    |
                    Counter2_OVERLOW_NO_CHANGE      |
                    Counter2_UNDERFLOW_NO_CHANGE);
        #else
            #if (Counter2__LEFT == Counter2_PWM_ALIGN)
                Counter2_TRIG_CONTROL2_REG = Counter2_PWM_MODE_LEFT;
            #endif  /* ( Counter2_PWM_LEFT == Counter2_PWM_ALIGN) */

            #if (Counter2__RIGHT == Counter2_PWM_ALIGN)
                Counter2_TRIG_CONTROL2_REG = Counter2_PWM_MODE_RIGHT;
            #endif  /* ( Counter2_PWM_RIGHT == Counter2_PWM_ALIGN) */

            #if (Counter2__CENTER == Counter2_PWM_ALIGN)
                Counter2_TRIG_CONTROL2_REG = Counter2_PWM_MODE_CENTER;
            #endif  /* ( Counter2_PWM_CENTER == Counter2_PWM_ALIGN) */

            #if (Counter2__ASYMMETRIC == Counter2_PWM_ALIGN)
                Counter2_TRIG_CONTROL2_REG = Counter2_PWM_MODE_ASYM;
            #endif  /* (Counter2__ASYMMETRIC == Counter2_PWM_ALIGN) */
        #endif  /* (Counter2__PWM_PR == Counter2_PWM_MODE) */

        /* Set other values from customizer */
        Counter2_WritePeriod(Counter2_PWM_PERIOD_VALUE );
        Counter2_WriteCompare(Counter2_PWM_COMPARE_VALUE);

        #if (1u == Counter2_PWM_COMPARE_SWAP)
            Counter2_SetCompareSwap(1u);
            Counter2_WriteCompareBuf(Counter2_PWM_COMPARE_BUF_VALUE);
        #endif  /* (1u == Counter2_PWM_COMPARE_SWAP) */

        #if (1u == Counter2_PWM_PERIOD_SWAP)
            Counter2_SetPeriodSwap(1u);
            Counter2_WritePeriodBuf(Counter2_PWM_PERIOD_BUF_VALUE);
        #endif  /* (1u == Counter2_PWM_PERIOD_SWAP) */
    #endif  /* (Counter2__PWM_SEL == Counter2_CONFIG) */
    
}


/*******************************************************************************
* Function Name: Counter2_Enable
********************************************************************************
*
* Summary:
*  Enables the Counter2.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_Enable(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    Counter2_BLOCK_CONTROL_REG |= Counter2_MASK;
    CyExitCriticalSection(enableInterrupts);

    /* Start Timer or PWM if start input is absent */
    #if (Counter2__PWM_SEL == Counter2_CONFIG)
        #if (0u == Counter2_PWM_START_SIGNAL_PRESENT)
            Counter2_TriggerCommand(Counter2_MASK, Counter2_CMD_START);
        #endif /* (0u == Counter2_PWM_START_SIGNAL_PRESENT) */
    #endif /* (Counter2__PWM_SEL == Counter2_CONFIG) */

    #if (Counter2__TIMER == Counter2_CONFIG)
        #if (0u == Counter2_TC_START_SIGNAL_PRESENT)
            Counter2_TriggerCommand(Counter2_MASK, Counter2_CMD_START);
        #endif /* (0u == Counter2_TC_START_SIGNAL_PRESENT) */
    #endif /* (Counter2__TIMER == Counter2_CONFIG) */
    
    #if (Counter2__QUAD == Counter2_CONFIG)
        #if (0u != Counter2_QUAD_AUTO_START)
            Counter2_TriggerCommand(Counter2_MASK, Counter2_CMD_RELOAD);
        #endif /* (0u != Counter2_QUAD_AUTO_START) */
    #endif  /* (Counter2__QUAD == Counter2_CONFIG) */
}


/*******************************************************************************
* Function Name: Counter2_Start
********************************************************************************
*
* Summary:
*  Initializes the Counter2 with default customizer
*  values when called the first time and enables the Counter2.
*  For subsequent calls the configuration is left unchanged and the component is
*  just enabled.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  Counter2_initVar: global variable is used to indicate initial
*  configuration of this component.  The variable is initialized to zero and set
*  to 1 the first time Counter2_Start() is called. This allows
*  enabling/disabling a component without re-initialization in all subsequent
*  calls to the Counter2_Start() routine.
*
*******************************************************************************/
void Counter2_Start(void)
{
    if (0u == Counter2_initVar)
    {
        Counter2_Init();
        Counter2_initVar = 1u;
    }

    Counter2_Enable();
}


/*******************************************************************************
* Function Name: Counter2_Stop
********************************************************************************
*
* Summary:
*  Disables the Counter2.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_Stop(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Counter2_BLOCK_CONTROL_REG &= (uint32)~Counter2_MASK;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Counter2_SetMode
********************************************************************************
*
* Summary:
*  Sets the operation mode of the Counter2. This function is used when
*  configured as a generic Counter2 and the actual mode of operation is
*  set at runtime. The mode must be set while the component is disabled.
*
* Parameters:
*  mode: Mode for the Counter2 to operate in
*   Values:
*   - Counter2_MODE_TIMER_COMPARE - Timer / Counter with
*                                                 compare capability
*         - Counter2_MODE_TIMER_CAPTURE - Timer / Counter with
*                                                 capture capability
*         - Counter2_MODE_QUAD - Quadrature decoder
*         - Counter2_MODE_PWM - PWM
*         - Counter2_MODE_PWM_DT - PWM with dead time
*         - Counter2_MODE_PWM_PR - PWM with pseudo random capability
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_SetMode(uint32 mode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Counter2_CONTROL_REG &= (uint32)~Counter2_MODE_MASK;
    Counter2_CONTROL_REG |= mode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Counter2_SetQDMode
********************************************************************************
*
* Summary:
*  Sets the the Quadrature Decoder to one of the 3 supported modes.
*  Its functionality is only applicable to Quadrature Decoder operation.
*
* Parameters:
*  qdMode: Quadrature Decoder mode
*   Values:
*         - Counter2_MODE_X1 - Counts on phi 1 rising
*         - Counter2_MODE_X2 - Counts on both edges of phi1 (2x faster)
*         - Counter2_MODE_X4 - Counts on both edges of phi1 and phi2
*                                        (4x faster)
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_SetQDMode(uint32 qdMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Counter2_CONTROL_REG &= (uint32)~Counter2_QUAD_MODE_MASK;
    Counter2_CONTROL_REG |= qdMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Counter2_SetPrescaler
********************************************************************************
*
* Summary:
*  Sets the prescaler value that is applied to the clock input.  Not applicable
*  to a PWM with the dead time mode or Quadrature Decoder mode.
*
* Parameters:
*  prescaler: Prescaler divider value
*   Values:
*         - Counter2_PRESCALE_DIVBY1    - Divide by 1 (no prescaling)
*         - Counter2_PRESCALE_DIVBY2    - Divide by 2
*         - Counter2_PRESCALE_DIVBY4    - Divide by 4
*         - Counter2_PRESCALE_DIVBY8    - Divide by 8
*         - Counter2_PRESCALE_DIVBY16   - Divide by 16
*         - Counter2_PRESCALE_DIVBY32   - Divide by 32
*         - Counter2_PRESCALE_DIVBY64   - Divide by 64
*         - Counter2_PRESCALE_DIVBY128  - Divide by 128
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_SetPrescaler(uint32 prescaler)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Counter2_CONTROL_REG &= (uint32)~Counter2_PRESCALER_MASK;
    Counter2_CONTROL_REG |= prescaler;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Counter2_SetOneShot
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the Counter2 runs
*  continuously or stops when terminal count is reached.  By default the
*  Counter2 operates in the continuous mode.
*
* Parameters:
*  oneShotEnable
*   Values:
*     - 0 - Continuous
*     - 1 - Enable One Shot
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_SetOneShot(uint32 oneShotEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Counter2_CONTROL_REG &= (uint32)~Counter2_ONESHOT_MASK;
    Counter2_CONTROL_REG |= ((uint32)((oneShotEnable & Counter2_1BIT_MASK) <<
                                                               Counter2_ONESHOT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Counter2_SetPWMMode
********************************************************************************
*
* Summary:
*  Writes the control register that determines what mode of operation the PWM
*  output lines are driven in.  There is a setting for what to do on a
*  comparison match (CC_MATCH), on an overflow (OVERFLOW) and on an underflow
*  (UNDERFLOW).  The value for each of the three must be ORed together to form
*  the mode.
*
* Parameters:
*  modeMask: A combination of three mode settings.  Mask must include a value
*  for each of the three or use one of the preconfigured PWM settings.
*   Values:
*     - CC_MATCH_SET        - Set on comparison match
*     - CC_MATCH_CLEAR      - Clear on comparison match
*     - CC_MATCH_INVERT     - Invert on comparison match
*     - CC_MATCH_NO_CHANGE  - No change on comparison match
*     - OVERLOW_SET         - Set on overflow
*     - OVERLOW_CLEAR       - Clear on  overflow
*     - OVERLOW_INVERT      - Invert on overflow
*     - OVERLOW_NO_CHANGE   - No change on overflow
*     - UNDERFLOW_SET       - Set on underflow
*     - UNDERFLOW_CLEAR     - Clear on underflow
*     - UNDERFLOW_INVERT    - Invert on underflow
*     - UNDERFLOW_NO_CHANGE - No change on underflow
*     - PWM_MODE_LEFT       - Setting for left aligned PWM.  Should be combined
*                             with up counting mode
*     - PWM_MODE_RIGHT      - Setting for right aligned PWM.  Should be combined
*                             with down counting mode
*     - PWM_MODE_CENTER     - Setting for center aligned PWM.  Should be
*                             combined with up/down 0 mode
*     - PWM_MODE_ASYM       - Setting for asymmetric PWM.  Should be combined
*                             with up/down 1 mode
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_SetPWMMode(uint32 modeMask)
{
    Counter2_TRIG_CONTROL2_REG = (modeMask & Counter2_6BIT_MASK);
}



/*******************************************************************************
* Function Name: Counter2_SetPWMSyncKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes asynchronous or synchronous kill operation.  By default the kill
*  operation is asynchronous.  This functionality is only applicable to the PWM
*  and PWM with dead time modes.
*
*  For Synchronous mode the kill signal disables both the line and line_n
*  signals until the next terminal count.
*
*  For Asynchronous mode the kill signal disables both the line and line_n
*  signals when the kill signal is present.  This mode should only be used
*  when the kill signal (stop input) is configured in the pass through mode
*  (Level sensitive signal).

*
* Parameters:
*  syncKillEnable
*   Values:
*     - 0 - Asynchronous
*     - 1 - Synchronous
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_SetPWMSyncKill(uint32 syncKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Counter2_CONTROL_REG &= (uint32)~Counter2_PWM_SYNC_KILL_MASK;
    Counter2_CONTROL_REG |= ((uint32)((syncKillEnable & Counter2_1BIT_MASK)  <<
                                               Counter2_PWM_SYNC_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Counter2_SetPWMStopOnKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes the PWM counter to stop.  By default the kill operation does not stop
*  the counter.  This functionality is only applicable to the three PWM modes.
*
*
* Parameters:
*  stopOnKillEnable
*   Values:
*     - 0 - Don't stop
*     - 1 - Stop
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_SetPWMStopOnKill(uint32 stopOnKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Counter2_CONTROL_REG &= (uint32)~Counter2_PWM_STOP_KILL_MASK;
    Counter2_CONTROL_REG |= ((uint32)((stopOnKillEnable & Counter2_1BIT_MASK)  <<
                                                         Counter2_PWM_STOP_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Counter2_SetPWMDeadTime
********************************************************************************
*
* Summary:
*  Writes the dead time control value.  This value delays the rising edge of
*  both the line and line_n signals the designated number of cycles resulting
*  in both signals being inactive for that many cycles.  This functionality is
*  only applicable to the PWM in the dead time mode.

*
* Parameters:
*  Dead time to insert
*   Values: 0 to 255
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_SetPWMDeadTime(uint32 deadTime)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Counter2_CONTROL_REG &= (uint32)~Counter2_PRESCALER_MASK;
    Counter2_CONTROL_REG |= ((uint32)((deadTime & Counter2_8BIT_MASK) <<
                                                          Counter2_PRESCALER_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Counter2_SetPWMInvert
********************************************************************************
*
* Summary:
*  Writes the bits that control whether the line and line_n outputs are
*  inverted from their normal output values.  This functionality is only
*  applicable to the three PWM modes.
*
* Parameters:
*  mask: Mask of outputs to invert.
*   Values:
*         - Counter2_INVERT_LINE   - Inverts the line output
*         - Counter2_INVERT_LINE_N - Inverts the line_n output
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_SetPWMInvert(uint32 mask)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Counter2_CONTROL_REG &= (uint32)~Counter2_INV_OUT_MASK;
    Counter2_CONTROL_REG |= mask;

    CyExitCriticalSection(enableInterrupts);
}



/*******************************************************************************
* Function Name: Counter2_WriteCounter
********************************************************************************
*
* Summary:
*  Writes a new 16bit counter value directly into the counter register, thus
*  setting the counter (not the period) to the value written. It is not
*  advised to write to this field when the counter is running.
*
* Parameters:
*  count: value to write
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_WriteCounter(uint32 count)
{
    Counter2_COUNTER_REG = (count & Counter2_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Counter2_ReadCounter
********************************************************************************
*
* Summary:
*  Reads the current counter value.
*
* Parameters:
*  None
*
* Return:
*  Current counter value
*
*******************************************************************************/
uint32 Counter2_ReadCounter(void)
{
    return (Counter2_COUNTER_REG & Counter2_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Counter2_SetCounterMode
********************************************************************************
*
* Summary:
*  Sets the counter mode.  Applicable to all modes except Quadrature Decoder
*  and the PWM with a pseudo random output.
*
* Parameters:
*  counterMode: Enumerated counter type values
*   Values:
*     - Counter2_COUNT_UP       - Counts up
*     - Counter2_COUNT_DOWN     - Counts down
*     - Counter2_COUNT_UPDOWN0  - Counts up and down. Terminal count
*                                         generated when counter reaches 0
*     - Counter2_COUNT_UPDOWN1  - Counts up and down. Terminal count
*                                         generated both when counter reaches 0
*                                         and period
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_SetCounterMode(uint32 counterMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Counter2_CONTROL_REG &= (uint32)~Counter2_UPDOWN_MASK;
    Counter2_CONTROL_REG |= counterMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Counter2_WritePeriod
********************************************************************************
*
* Summary:
*  Writes the 16 bit period register with the new period value.
*  To cause the counter to count for N cycles this register should be written
*  with N-1 (counts from 0 to period inclusive).
*
* Parameters:
*  period: Period value
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_WritePeriod(uint32 period)
{
    Counter2_PERIOD_REG = (period & Counter2_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Counter2_ReadPeriod
********************************************************************************
*
* Summary:
*  Reads the 16 bit period register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 Counter2_ReadPeriod(void)
{
    return (Counter2_PERIOD_REG & Counter2_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Counter2_SetCompareSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the compare registers are
*  swapped. When enabled in the Timer/Counter mode(without capture) the swap
*  occurs at a TC event. In the PWM mode the swap occurs at the next TC event
*  following a hardware switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_SetCompareSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Counter2_CONTROL_REG &= (uint32)~Counter2_RELOAD_CC_MASK;
    Counter2_CONTROL_REG |= (swapEnable & Counter2_1BIT_MASK);

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Counter2_WritePeriodBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit period buf register with the new period value.
*
* Parameters:
*  periodBuf: Period value
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_WritePeriodBuf(uint32 periodBuf)
{
    Counter2_PERIOD_BUF_REG = (periodBuf & Counter2_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Counter2_ReadPeriodBuf
********************************************************************************
*
* Summary:
*  Reads the 16 bit period buf register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 Counter2_ReadPeriodBuf(void)
{
    return (Counter2_PERIOD_BUF_REG & Counter2_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Counter2_SetPeriodSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the period registers are
*  swapped. When enabled in Timer/Counter mode the swap occurs at a TC event.
*  In the PWM mode the swap occurs at the next TC event following a hardware
*  switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_SetPeriodSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Counter2_CONTROL_REG &= (uint32)~Counter2_RELOAD_PERIOD_MASK;
    Counter2_CONTROL_REG |= ((uint32)((swapEnable & Counter2_1BIT_MASK) <<
                                                            Counter2_RELOAD_PERIOD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Counter2_WriteCompare
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compare: Compare value
*
* Return:
*  None
*
* Note:
*  It is not recommended to use the value equal to "0" or equal to 
*  "period value" in Center or Asymmetric align PWM modes on the 
*  PSoC 4100/PSoC 4200 devices.
*  PSoC 4000 devices write the 16 bit compare register with the decremented 
*  compare value in the Up counting mode (except 0x0u), and the incremented 
*  compare value in the Down counting mode (except 0xFFFFu).
*
*******************************************************************************/
void Counter2_WriteCompare(uint32 compare)
{
    #if (Counter2_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (Counter2_CY_TCPWM_4000) */

    #if (Counter2_CY_TCPWM_4000)
        currentMode = ((Counter2_CONTROL_REG & Counter2_UPDOWN_MASK) >> Counter2_UPDOWN_SHIFT);

        if (((uint32)Counter2__COUNT_DOWN == currentMode) && (0xFFFFu != compare))
        {
            compare++;
        }
        else if (((uint32)Counter2__COUNT_UP == currentMode) && (0u != compare))
        {
            compare--;
        }
        else
        {
        }
        
    
    #endif /* (Counter2_CY_TCPWM_4000) */
    
    Counter2_COMP_CAP_REG = (compare & Counter2_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Counter2_ReadCompare
********************************************************************************
*
* Summary:
*  Reads the compare register. Not applicable for Timer/Counter with Capture
*  or in Quadrature Decoder modes.
*  PSoC 4000 devices read the incremented compare register value in the 
*  Up counting mode (except 0xFFFFu), and the decremented value in the 
*  Down counting mode (except 0x0u).
*
* Parameters:
*  None
*
* Return:
*  Compare value
*
* Note:
*  PSoC 4000 devices read the incremented compare register value in the 
*  Up counting mode (except 0xFFFFu), and the decremented value in the 
*  Down counting mode (except 0x0u).
*
*******************************************************************************/
uint32 Counter2_ReadCompare(void)
{
    #if (Counter2_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (Counter2_CY_TCPWM_4000) */

    #if (Counter2_CY_TCPWM_4000)
        currentMode = ((Counter2_CONTROL_REG & Counter2_UPDOWN_MASK) >> Counter2_UPDOWN_SHIFT);
        
        regVal = Counter2_COMP_CAP_REG;
        
        if (((uint32)Counter2__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)Counter2__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & Counter2_16BIT_MASK);
    #else
        return (Counter2_COMP_CAP_REG & Counter2_16BIT_MASK);
    #endif /* (Counter2_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: Counter2_WriteCompareBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare buffer register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compareBuf: Compare value
*
* Return:
*  None
*
* Note:
*  It is not recommended to use the value equal to "0" or equal to 
*  "period value" in Center or Asymmetric align PWM modes on the 
*  PSoC 4100/PSoC 4200 devices.
*  PSoC 4000 devices write the 16 bit compare register with the decremented 
*  compare value in the Up counting mode (except 0x0u), and the incremented 
*  compare value in the Down counting mode (except 0xFFFFu).
*
*******************************************************************************/
void Counter2_WriteCompareBuf(uint32 compareBuf)
{
    #if (Counter2_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (Counter2_CY_TCPWM_4000) */

    #if (Counter2_CY_TCPWM_4000)
        currentMode = ((Counter2_CONTROL_REG & Counter2_UPDOWN_MASK) >> Counter2_UPDOWN_SHIFT);

        if (((uint32)Counter2__COUNT_DOWN == currentMode) && (0xFFFFu != compareBuf))
        {
            compareBuf++;
        }
        else if (((uint32)Counter2__COUNT_UP == currentMode) && (0u != compareBuf))
        {
            compareBuf --;
        }
        else
        {
        }
    #endif /* (Counter2_CY_TCPWM_4000) */
    
    Counter2_COMP_CAP_BUF_REG = (compareBuf & Counter2_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Counter2_ReadCompareBuf
********************************************************************************
*
* Summary:
*  Reads the compare buffer register. Not applicable for Timer/Counter with
*  Capture or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare buffer value
*
* Note:
*  PSoC 4000 devices read the incremented compare register value in the 
*  Up counting mode (except 0xFFFFu), and the decremented value in the 
*  Down counting mode (except 0x0u).
*
*******************************************************************************/
uint32 Counter2_ReadCompareBuf(void)
{
    #if (Counter2_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (Counter2_CY_TCPWM_4000) */

    #if (Counter2_CY_TCPWM_4000)
        currentMode = ((Counter2_CONTROL_REG & Counter2_UPDOWN_MASK) >> Counter2_UPDOWN_SHIFT);

        regVal = Counter2_COMP_CAP_BUF_REG;
        
        if (((uint32)Counter2__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)Counter2__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & Counter2_16BIT_MASK);
    #else
        return (Counter2_COMP_CAP_BUF_REG & Counter2_16BIT_MASK);
    #endif /* (Counter2_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: Counter2_ReadCapture
********************************************************************************
*
* Summary:
*  Reads the captured counter value. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture value
*
*******************************************************************************/
uint32 Counter2_ReadCapture(void)
{
    return (Counter2_COMP_CAP_REG & Counter2_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Counter2_ReadCaptureBuf
********************************************************************************
*
* Summary:
*  Reads the capture buffer register. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture buffer value
*
*******************************************************************************/
uint32 Counter2_ReadCaptureBuf(void)
{
    return (Counter2_COMP_CAP_BUF_REG & Counter2_16BIT_MASK);
}


/*******************************************************************************
* Function Name: Counter2_SetCaptureMode
********************************************************************************
*
* Summary:
*  Sets the capture trigger mode. For PWM mode this is the switch input.
*  This input is not applicable to the Timer/Counter without Capture and
*  Quadrature Decoder modes.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - Counter2_TRIG_LEVEL     - Level
*     - Counter2_TRIG_RISING    - Rising edge
*     - Counter2_TRIG_FALLING   - Falling edge
*     - Counter2_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_SetCaptureMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Counter2_TRIG_CONTROL1_REG &= (uint32)~Counter2_CAPTURE_MASK;
    Counter2_TRIG_CONTROL1_REG |= triggerMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Counter2_SetReloadMode
********************************************************************************
*
* Summary:
*  Sets the reload trigger mode. For Quadrature Decoder mode this is the index
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - Counter2_TRIG_LEVEL     - Level
*     - Counter2_TRIG_RISING    - Rising edge
*     - Counter2_TRIG_FALLING   - Falling edge
*     - Counter2_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_SetReloadMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Counter2_TRIG_CONTROL1_REG &= (uint32)~Counter2_RELOAD_MASK;
    Counter2_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << Counter2_RELOAD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Counter2_SetStartMode
********************************************************************************
*
* Summary:
*  Sets the start trigger mode. For Quadrature Decoder mode this is the
*  phiB input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - Counter2_TRIG_LEVEL     - Level
*     - Counter2_TRIG_RISING    - Rising edge
*     - Counter2_TRIG_FALLING   - Falling edge
*     - Counter2_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_SetStartMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Counter2_TRIG_CONTROL1_REG &= (uint32)~Counter2_START_MASK;
    Counter2_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << Counter2_START_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Counter2_SetStopMode
********************************************************************************
*
* Summary:
*  Sets the stop trigger mode. For PWM mode this is the kill input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - Counter2_TRIG_LEVEL     - Level
*     - Counter2_TRIG_RISING    - Rising edge
*     - Counter2_TRIG_FALLING   - Falling edge
*     - Counter2_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_SetStopMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Counter2_TRIG_CONTROL1_REG &= (uint32)~Counter2_STOP_MASK;
    Counter2_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << Counter2_STOP_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Counter2_SetCountMode
********************************************************************************
*
* Summary:
*  Sets the count trigger mode. For Quadrature Decoder mode this is the phiA
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - Counter2_TRIG_LEVEL     - Level
*     - Counter2_TRIG_RISING    - Rising edge
*     - Counter2_TRIG_FALLING   - Falling edge
*     - Counter2_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_SetCountMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Counter2_TRIG_CONTROL1_REG &= (uint32)~Counter2_COUNT_MASK;
    Counter2_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << Counter2_COUNT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Counter2_TriggerCommand
********************************************************************************
*
* Summary:
*  Triggers the designated command to occur on the designated TCPWM instances.
*  The mask can be used to apply this command simultaneously to more than one
*  instance.  This allows multiple TCPWM instances to be synchronized.
*
* Parameters:
*  mask: A combination of mask bits for each instance of the TCPWM that the
*        command should apply to.  This function from one instance can be used
*        to apply the command to any of the instances in the design.
*        The mask value for a specific instance is available with the MASK
*        define.
*  command: Enumerated command values. Capture command only applicable for
*           Timer/Counter with Capture and PWM modes.
*   Values:
*     - Counter2_CMD_CAPTURE    - Trigger Capture/Switch command
*     - Counter2_CMD_RELOAD     - Trigger Reload/Index command
*     - Counter2_CMD_STOP       - Trigger Stop/Kill command
*     - Counter2_CMD_START      - Trigger Start/phiB command
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_TriggerCommand(uint32 mask, uint32 command)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    Counter2_COMMAND_REG = ((uint32)(mask << command));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: Counter2_ReadStatus
********************************************************************************
*
* Summary:
*  Reads the status of the Counter2.
*
* Parameters:
*  None
*
* Return:
*  Status
*   Values:
*     - Counter2_STATUS_DOWN    - Set if counting down
*     - Counter2_STATUS_RUNNING - Set if counter is running
*
*******************************************************************************/
uint32 Counter2_ReadStatus(void)
{
    return ((Counter2_STATUS_REG >> Counter2_RUNNING_STATUS_SHIFT) |
            (Counter2_STATUS_REG & Counter2_STATUS_DOWN));
}


/*******************************************************************************
* Function Name: Counter2_SetInterruptMode
********************************************************************************
*
* Summary:
*  Sets the interrupt mask to control which interrupt
*  requests generate the interrupt signal.
*
* Parameters:
*   interruptMask: Mask of bits to be enabled
*   Values:
*     - Counter2_INTR_MASK_TC       - Terminal count mask
*     - Counter2_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_SetInterruptMode(uint32 interruptMask)
{
    Counter2_INTERRUPT_MASK_REG =  interruptMask;
}


/*******************************************************************************
* Function Name: Counter2_GetInterruptSourceMasked
********************************************************************************
*
* Summary:
*  Gets the interrupt requests masked by the interrupt mask.
*
* Parameters:
*   None
*
* Return:
*  Masked interrupt source
*   Values:
*     - Counter2_INTR_MASK_TC       - Terminal count mask
*     - Counter2_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 Counter2_GetInterruptSourceMasked(void)
{
    return (Counter2_INTERRUPT_MASKED_REG);
}


/*******************************************************************************
* Function Name: Counter2_GetInterruptSource
********************************************************************************
*
* Summary:
*  Gets the interrupt requests (without masking).
*
* Parameters:
*  None
*
* Return:
*  Interrupt request value
*   Values:
*     - Counter2_INTR_MASK_TC       - Terminal count mask
*     - Counter2_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 Counter2_GetInterruptSource(void)
{
    return (Counter2_INTERRUPT_REQ_REG);
}


/*******************************************************************************
* Function Name: Counter2_ClearInterrupt
********************************************************************************
*
* Summary:
*  Clears the interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to clear
*   Values:
*     - Counter2_INTR_MASK_TC       - Terminal count mask
*     - Counter2_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_ClearInterrupt(uint32 interruptMask)
{
    Counter2_INTERRUPT_REQ_REG = interruptMask;
}


/*******************************************************************************
* Function Name: Counter2_SetInterrupt
********************************************************************************
*
* Summary:
*  Sets a software interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to set
*   Values:
*     - Counter2_INTR_MASK_TC       - Terminal count mask
*     - Counter2_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_SetInterrupt(uint32 interruptMask)
{
    Counter2_INTERRUPT_SET_REG = interruptMask;
}


/* [] END OF FILE */
