/*******************************************************************************
* File Name: Counter2.h
* Version 2.10
*
* Description:
*  This file provides constants and parameter values for the Counter2
*  component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_TCPWM_Counter2_H)
#define CY_TCPWM_Counter2_H


#include "CyLib.h"
#include "cytypes.h"
#include "cyfitter.h"


/*******************************************************************************
* Internal Type defines
*******************************************************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} Counter2_BACKUP_STRUCT;


/*******************************************************************************
* Variables
*******************************************************************************/
extern uint8  Counter2_initVar;


/***************************************
*   Conditional Compilation Parameters
****************************************/

#define Counter2_CY_TCPWM_V2                    (CYIPBLOCK_m0s8tcpwm_VERSION == 2u)
#define Counter2_CY_TCPWM_4000                  (CY_PSOC4_4000)

/* TCPWM Configuration */
#define Counter2_CONFIG                         (7lu)

/* Quad Mode */
/* Parameters */
#define Counter2_QUAD_ENCODING_MODES            (0lu)
#define Counter2_QUAD_AUTO_START                (1lu)

/* Signal modes */
#define Counter2_QUAD_INDEX_SIGNAL_MODE         (0lu)
#define Counter2_QUAD_PHIA_SIGNAL_MODE          (3lu)
#define Counter2_QUAD_PHIB_SIGNAL_MODE          (3lu)
#define Counter2_QUAD_STOP_SIGNAL_MODE          (0lu)

/* Signal present */
#define Counter2_QUAD_INDEX_SIGNAL_PRESENT      (0lu)
#define Counter2_QUAD_STOP_SIGNAL_PRESENT       (0lu)

/* Interrupt Mask */
#define Counter2_QUAD_INTERRUPT_MASK            (1lu)

/* Timer/Counter Mode */
/* Parameters */
#define Counter2_TC_RUN_MODE                    (0lu)
#define Counter2_TC_COUNTER_MODE                (0lu)
#define Counter2_TC_COMP_CAP_MODE               (2lu)
#define Counter2_TC_PRESCALER                   (0lu)

/* Signal modes */
#define Counter2_TC_RELOAD_SIGNAL_MODE          (0lu)
#define Counter2_TC_COUNT_SIGNAL_MODE           (3lu)
#define Counter2_TC_START_SIGNAL_MODE           (0lu)
#define Counter2_TC_STOP_SIGNAL_MODE            (0lu)
#define Counter2_TC_CAPTURE_SIGNAL_MODE         (0lu)

/* Signal present */
#define Counter2_TC_RELOAD_SIGNAL_PRESENT       (0lu)
#define Counter2_TC_COUNT_SIGNAL_PRESENT        (0lu)
#define Counter2_TC_START_SIGNAL_PRESENT        (0lu)
#define Counter2_TC_STOP_SIGNAL_PRESENT         (0lu)
#define Counter2_TC_CAPTURE_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define Counter2_TC_INTERRUPT_MASK              (1lu)

/* PWM Mode */
/* Parameters */
#define Counter2_PWM_KILL_EVENT                 (0lu)
#define Counter2_PWM_STOP_EVENT                 (0lu)
#define Counter2_PWM_MODE                       (4lu)
#define Counter2_PWM_OUT_N_INVERT               (0lu)
#define Counter2_PWM_OUT_INVERT                 (0lu)
#define Counter2_PWM_ALIGN                      (0lu)
#define Counter2_PWM_RUN_MODE                   (0lu)
#define Counter2_PWM_DEAD_TIME_CYCLE            (0lu)
#define Counter2_PWM_PRESCALER                  (0lu)

/* Signal modes */
#define Counter2_PWM_RELOAD_SIGNAL_MODE         (0lu)
#define Counter2_PWM_COUNT_SIGNAL_MODE          (0lu)
#define Counter2_PWM_START_SIGNAL_MODE          (0lu)
#define Counter2_PWM_STOP_SIGNAL_MODE           (0lu)
#define Counter2_PWM_SWITCH_SIGNAL_MODE         (0lu)

/* Signal present */
#define Counter2_PWM_RELOAD_SIGNAL_PRESENT      (0lu)
#define Counter2_PWM_COUNT_SIGNAL_PRESENT       (1lu)
#define Counter2_PWM_START_SIGNAL_PRESENT       (1lu)
#define Counter2_PWM_STOP_SIGNAL_PRESENT        (1lu)
#define Counter2_PWM_SWITCH_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define Counter2_PWM_INTERRUPT_MASK             (0lu)


/***************************************
*    Initial Parameter Constants
***************************************/

/* Timer/Counter Mode */
#define Counter2_TC_PERIOD_VALUE                (65535lu)
#define Counter2_TC_COMPARE_VALUE               (65535lu)
#define Counter2_TC_COMPARE_BUF_VALUE           (65535lu)
#define Counter2_TC_COMPARE_SWAP                (0lu)

/* PWM Mode */
#define Counter2_PWM_PERIOD_VALUE               (10000lu)
#define Counter2_PWM_PERIOD_BUF_VALUE           (65535lu)
#define Counter2_PWM_PERIOD_SWAP                (0lu)
#define Counter2_PWM_COMPARE_VALUE              (5000lu)
#define Counter2_PWM_COMPARE_BUF_VALUE          (65535lu)
#define Counter2_PWM_COMPARE_SWAP               (0lu)


/***************************************
*    Enumerated Types and Parameters
***************************************/

#define Counter2__LEFT 0
#define Counter2__RIGHT 1
#define Counter2__CENTER 2
#define Counter2__ASYMMETRIC 3

#define Counter2__X1 0
#define Counter2__X2 1
#define Counter2__X4 2

#define Counter2__PWM 4
#define Counter2__PWM_DT 5
#define Counter2__PWM_PR 6

#define Counter2__INVERSE 1
#define Counter2__DIRECT 0

#define Counter2__CAPTURE 2
#define Counter2__COMPARE 0

#define Counter2__TRIG_LEVEL 3
#define Counter2__TRIG_RISING 0
#define Counter2__TRIG_FALLING 1
#define Counter2__TRIG_BOTH 2

#define Counter2__INTR_MASK_TC 1
#define Counter2__INTR_MASK_CC_MATCH 2
#define Counter2__INTR_MASK_NONE 0
#define Counter2__INTR_MASK_TC_CC 3

#define Counter2__UNCONFIG 8
#define Counter2__TIMER 1
#define Counter2__QUAD 3
#define Counter2__PWM_SEL 7

#define Counter2__COUNT_UP 0
#define Counter2__COUNT_DOWN 1
#define Counter2__COUNT_UPDOWN0 2
#define Counter2__COUNT_UPDOWN1 3


/* Prescaler */
#define Counter2_PRESCALE_DIVBY1                ((uint32)(0u << Counter2_PRESCALER_SHIFT))
#define Counter2_PRESCALE_DIVBY2                ((uint32)(1u << Counter2_PRESCALER_SHIFT))
#define Counter2_PRESCALE_DIVBY4                ((uint32)(2u << Counter2_PRESCALER_SHIFT))
#define Counter2_PRESCALE_DIVBY8                ((uint32)(3u << Counter2_PRESCALER_SHIFT))
#define Counter2_PRESCALE_DIVBY16               ((uint32)(4u << Counter2_PRESCALER_SHIFT))
#define Counter2_PRESCALE_DIVBY32               ((uint32)(5u << Counter2_PRESCALER_SHIFT))
#define Counter2_PRESCALE_DIVBY64               ((uint32)(6u << Counter2_PRESCALER_SHIFT))
#define Counter2_PRESCALE_DIVBY128              ((uint32)(7u << Counter2_PRESCALER_SHIFT))

/* TCPWM set modes */
#define Counter2_MODE_TIMER_COMPARE             ((uint32)(Counter2__COMPARE         <<  \
                                                                  Counter2_MODE_SHIFT))
#define Counter2_MODE_TIMER_CAPTURE             ((uint32)(Counter2__CAPTURE         <<  \
                                                                  Counter2_MODE_SHIFT))
#define Counter2_MODE_QUAD                      ((uint32)(Counter2__QUAD            <<  \
                                                                  Counter2_MODE_SHIFT))
#define Counter2_MODE_PWM                       ((uint32)(Counter2__PWM             <<  \
                                                                  Counter2_MODE_SHIFT))
#define Counter2_MODE_PWM_DT                    ((uint32)(Counter2__PWM_DT          <<  \
                                                                  Counter2_MODE_SHIFT))
#define Counter2_MODE_PWM_PR                    ((uint32)(Counter2__PWM_PR          <<  \
                                                                  Counter2_MODE_SHIFT))

/* Quad Modes */
#define Counter2_MODE_X1                        ((uint32)(Counter2__X1              <<  \
                                                                  Counter2_QUAD_MODE_SHIFT))
#define Counter2_MODE_X2                        ((uint32)(Counter2__X2              <<  \
                                                                  Counter2_QUAD_MODE_SHIFT))
#define Counter2_MODE_X4                        ((uint32)(Counter2__X4              <<  \
                                                                  Counter2_QUAD_MODE_SHIFT))

/* Counter modes */
#define Counter2_COUNT_UP                       ((uint32)(Counter2__COUNT_UP        <<  \
                                                                  Counter2_UPDOWN_SHIFT))
#define Counter2_COUNT_DOWN                     ((uint32)(Counter2__COUNT_DOWN      <<  \
                                                                  Counter2_UPDOWN_SHIFT))
#define Counter2_COUNT_UPDOWN0                  ((uint32)(Counter2__COUNT_UPDOWN0   <<  \
                                                                  Counter2_UPDOWN_SHIFT))
#define Counter2_COUNT_UPDOWN1                  ((uint32)(Counter2__COUNT_UPDOWN1   <<  \
                                                                  Counter2_UPDOWN_SHIFT))

/* PWM output invert */
#define Counter2_INVERT_LINE                    ((uint32)(Counter2__INVERSE         <<  \
                                                                  Counter2_INV_OUT_SHIFT))
#define Counter2_INVERT_LINE_N                  ((uint32)(Counter2__INVERSE         <<  \
                                                                  Counter2_INV_COMPL_OUT_SHIFT))

/* Trigger modes */
#define Counter2_TRIG_RISING                    ((uint32)Counter2__TRIG_RISING)
#define Counter2_TRIG_FALLING                   ((uint32)Counter2__TRIG_FALLING)
#define Counter2_TRIG_BOTH                      ((uint32)Counter2__TRIG_BOTH)
#define Counter2_TRIG_LEVEL                     ((uint32)Counter2__TRIG_LEVEL)

/* Interrupt mask */
#define Counter2_INTR_MASK_TC                   ((uint32)Counter2__INTR_MASK_TC)
#define Counter2_INTR_MASK_CC_MATCH             ((uint32)Counter2__INTR_MASK_CC_MATCH)

/* PWM Output Controls */
#define Counter2_CC_MATCH_SET                   (0x00u)
#define Counter2_CC_MATCH_CLEAR                 (0x01u)
#define Counter2_CC_MATCH_INVERT                (0x02u)
#define Counter2_CC_MATCH_NO_CHANGE             (0x03u)
#define Counter2_OVERLOW_SET                    (0x00u)
#define Counter2_OVERLOW_CLEAR                  (0x04u)
#define Counter2_OVERLOW_INVERT                 (0x08u)
#define Counter2_OVERLOW_NO_CHANGE              (0x0Cu)
#define Counter2_UNDERFLOW_SET                  (0x00u)
#define Counter2_UNDERFLOW_CLEAR                (0x10u)
#define Counter2_UNDERFLOW_INVERT               (0x20u)
#define Counter2_UNDERFLOW_NO_CHANGE            (0x30u)

/* PWM Align */
#define Counter2_PWM_MODE_LEFT                  (Counter2_CC_MATCH_CLEAR        |   \
                                                         Counter2_OVERLOW_SET           |   \
                                                         Counter2_UNDERFLOW_NO_CHANGE)
#define Counter2_PWM_MODE_RIGHT                 (Counter2_CC_MATCH_SET          |   \
                                                         Counter2_OVERLOW_NO_CHANGE     |   \
                                                         Counter2_UNDERFLOW_CLEAR)
#define Counter2_PWM_MODE_ASYM                  (Counter2_CC_MATCH_INVERT       |   \
                                                         Counter2_OVERLOW_SET           |   \
                                                         Counter2_UNDERFLOW_CLEAR)

#if (Counter2_CY_TCPWM_V2)
    #if(Counter2_CY_TCPWM_4000)
        #define Counter2_PWM_MODE_CENTER                (Counter2_CC_MATCH_INVERT       |   \
                                                                 Counter2_OVERLOW_NO_CHANGE     |   \
                                                                 Counter2_UNDERFLOW_CLEAR)
    #else
        #define Counter2_PWM_MODE_CENTER                (Counter2_CC_MATCH_INVERT       |   \
                                                                 Counter2_OVERLOW_SET           |   \
                                                                 Counter2_UNDERFLOW_CLEAR)
    #endif /* (Counter2_CY_TCPWM_4000) */
#else
    #define Counter2_PWM_MODE_CENTER                (Counter2_CC_MATCH_INVERT       |   \
                                                             Counter2_OVERLOW_NO_CHANGE     |   \
                                                             Counter2_UNDERFLOW_CLEAR)
#endif /* (Counter2_CY_TCPWM_NEW) */

/* Command operations without condition */
#define Counter2_CMD_CAPTURE                    (0u)
#define Counter2_CMD_RELOAD                     (8u)
#define Counter2_CMD_STOP                       (16u)
#define Counter2_CMD_START                      (24u)

/* Status */
#define Counter2_STATUS_DOWN                    (1u)
#define Counter2_STATUS_RUNNING                 (2u)


/***************************************
*        Function Prototypes
****************************************/

void   Counter2_Init(void);
void   Counter2_Enable(void);
void   Counter2_Start(void);
void   Counter2_Stop(void);

void   Counter2_SetMode(uint32 mode);
void   Counter2_SetCounterMode(uint32 counterMode);
void   Counter2_SetPWMMode(uint32 modeMask);
void   Counter2_SetQDMode(uint32 qdMode);

void   Counter2_SetPrescaler(uint32 prescaler);
void   Counter2_TriggerCommand(uint32 mask, uint32 command);
void   Counter2_SetOneShot(uint32 oneShotEnable);
uint32 Counter2_ReadStatus(void);

void   Counter2_SetPWMSyncKill(uint32 syncKillEnable);
void   Counter2_SetPWMStopOnKill(uint32 stopOnKillEnable);
void   Counter2_SetPWMDeadTime(uint32 deadTime);
void   Counter2_SetPWMInvert(uint32 mask);

void   Counter2_SetInterruptMode(uint32 interruptMask);
uint32 Counter2_GetInterruptSourceMasked(void);
uint32 Counter2_GetInterruptSource(void);
void   Counter2_ClearInterrupt(uint32 interruptMask);
void   Counter2_SetInterrupt(uint32 interruptMask);

void   Counter2_WriteCounter(uint32 count);
uint32 Counter2_ReadCounter(void);

uint32 Counter2_ReadCapture(void);
uint32 Counter2_ReadCaptureBuf(void);

void   Counter2_WritePeriod(uint32 period);
uint32 Counter2_ReadPeriod(void);
void   Counter2_WritePeriodBuf(uint32 periodBuf);
uint32 Counter2_ReadPeriodBuf(void);

void   Counter2_WriteCompare(uint32 compare);
uint32 Counter2_ReadCompare(void);
void   Counter2_WriteCompareBuf(uint32 compareBuf);
uint32 Counter2_ReadCompareBuf(void);

void   Counter2_SetPeriodSwap(uint32 swapEnable);
void   Counter2_SetCompareSwap(uint32 swapEnable);

void   Counter2_SetCaptureMode(uint32 triggerMode);
void   Counter2_SetReloadMode(uint32 triggerMode);
void   Counter2_SetStartMode(uint32 triggerMode);
void   Counter2_SetStopMode(uint32 triggerMode);
void   Counter2_SetCountMode(uint32 triggerMode);

void   Counter2_SaveConfig(void);
void   Counter2_RestoreConfig(void);
void   Counter2_Sleep(void);
void   Counter2_Wakeup(void);


/***************************************
*             Registers
***************************************/

#define Counter2_BLOCK_CONTROL_REG              (*(reg32 *) Counter2_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define Counter2_BLOCK_CONTROL_PTR              ( (reg32 *) Counter2_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define Counter2_COMMAND_REG                    (*(reg32 *) Counter2_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define Counter2_COMMAND_PTR                    ( (reg32 *) Counter2_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define Counter2_INTRRUPT_CAUSE_REG             (*(reg32 *) Counter2_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define Counter2_INTRRUPT_CAUSE_PTR             ( (reg32 *) Counter2_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define Counter2_CONTROL_REG                    (*(reg32 *) Counter2_cy_m0s8_tcpwm_1__CTRL )
#define Counter2_CONTROL_PTR                    ( (reg32 *) Counter2_cy_m0s8_tcpwm_1__CTRL )
#define Counter2_STATUS_REG                     (*(reg32 *) Counter2_cy_m0s8_tcpwm_1__STATUS )
#define Counter2_STATUS_PTR                     ( (reg32 *) Counter2_cy_m0s8_tcpwm_1__STATUS )
#define Counter2_COUNTER_REG                    (*(reg32 *) Counter2_cy_m0s8_tcpwm_1__COUNTER )
#define Counter2_COUNTER_PTR                    ( (reg32 *) Counter2_cy_m0s8_tcpwm_1__COUNTER )
#define Counter2_COMP_CAP_REG                   (*(reg32 *) Counter2_cy_m0s8_tcpwm_1__CC )
#define Counter2_COMP_CAP_PTR                   ( (reg32 *) Counter2_cy_m0s8_tcpwm_1__CC )
#define Counter2_COMP_CAP_BUF_REG               (*(reg32 *) Counter2_cy_m0s8_tcpwm_1__CC_BUFF )
#define Counter2_COMP_CAP_BUF_PTR               ( (reg32 *) Counter2_cy_m0s8_tcpwm_1__CC_BUFF )
#define Counter2_PERIOD_REG                     (*(reg32 *) Counter2_cy_m0s8_tcpwm_1__PERIOD )
#define Counter2_PERIOD_PTR                     ( (reg32 *) Counter2_cy_m0s8_tcpwm_1__PERIOD )
#define Counter2_PERIOD_BUF_REG                 (*(reg32 *) Counter2_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define Counter2_PERIOD_BUF_PTR                 ( (reg32 *) Counter2_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define Counter2_TRIG_CONTROL0_REG              (*(reg32 *) Counter2_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define Counter2_TRIG_CONTROL0_PTR              ( (reg32 *) Counter2_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define Counter2_TRIG_CONTROL1_REG              (*(reg32 *) Counter2_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define Counter2_TRIG_CONTROL1_PTR              ( (reg32 *) Counter2_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define Counter2_TRIG_CONTROL2_REG              (*(reg32 *) Counter2_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define Counter2_TRIG_CONTROL2_PTR              ( (reg32 *) Counter2_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define Counter2_INTERRUPT_REQ_REG              (*(reg32 *) Counter2_cy_m0s8_tcpwm_1__INTR )
#define Counter2_INTERRUPT_REQ_PTR              ( (reg32 *) Counter2_cy_m0s8_tcpwm_1__INTR )
#define Counter2_INTERRUPT_SET_REG              (*(reg32 *) Counter2_cy_m0s8_tcpwm_1__INTR_SET )
#define Counter2_INTERRUPT_SET_PTR              ( (reg32 *) Counter2_cy_m0s8_tcpwm_1__INTR_SET )
#define Counter2_INTERRUPT_MASK_REG             (*(reg32 *) Counter2_cy_m0s8_tcpwm_1__INTR_MASK )
#define Counter2_INTERRUPT_MASK_PTR             ( (reg32 *) Counter2_cy_m0s8_tcpwm_1__INTR_MASK )
#define Counter2_INTERRUPT_MASKED_REG           (*(reg32 *) Counter2_cy_m0s8_tcpwm_1__INTR_MASKED )
#define Counter2_INTERRUPT_MASKED_PTR           ( (reg32 *) Counter2_cy_m0s8_tcpwm_1__INTR_MASKED )


/***************************************
*       Registers Constants
***************************************/

/* Mask */
#define Counter2_MASK                           ((uint32)Counter2_cy_m0s8_tcpwm_1__TCPWM_CTRL_MASK)

/* Shift constants for control register */
#define Counter2_RELOAD_CC_SHIFT                (0u)
#define Counter2_RELOAD_PERIOD_SHIFT            (1u)
#define Counter2_PWM_SYNC_KILL_SHIFT            (2u)
#define Counter2_PWM_STOP_KILL_SHIFT            (3u)
#define Counter2_PRESCALER_SHIFT                (8u)
#define Counter2_UPDOWN_SHIFT                   (16u)
#define Counter2_ONESHOT_SHIFT                  (18u)
#define Counter2_QUAD_MODE_SHIFT                (20u)
#define Counter2_INV_OUT_SHIFT                  (20u)
#define Counter2_INV_COMPL_OUT_SHIFT            (21u)
#define Counter2_MODE_SHIFT                     (24u)

/* Mask constants for control register */
#define Counter2_RELOAD_CC_MASK                 ((uint32)(Counter2_1BIT_MASK        <<  \
                                                                            Counter2_RELOAD_CC_SHIFT))
#define Counter2_RELOAD_PERIOD_MASK             ((uint32)(Counter2_1BIT_MASK        <<  \
                                                                            Counter2_RELOAD_PERIOD_SHIFT))
#define Counter2_PWM_SYNC_KILL_MASK             ((uint32)(Counter2_1BIT_MASK        <<  \
                                                                            Counter2_PWM_SYNC_KILL_SHIFT))
#define Counter2_PWM_STOP_KILL_MASK             ((uint32)(Counter2_1BIT_MASK        <<  \
                                                                            Counter2_PWM_STOP_KILL_SHIFT))
#define Counter2_PRESCALER_MASK                 ((uint32)(Counter2_8BIT_MASK        <<  \
                                                                            Counter2_PRESCALER_SHIFT))
#define Counter2_UPDOWN_MASK                    ((uint32)(Counter2_2BIT_MASK        <<  \
                                                                            Counter2_UPDOWN_SHIFT))
#define Counter2_ONESHOT_MASK                   ((uint32)(Counter2_1BIT_MASK        <<  \
                                                                            Counter2_ONESHOT_SHIFT))
#define Counter2_QUAD_MODE_MASK                 ((uint32)(Counter2_3BIT_MASK        <<  \
                                                                            Counter2_QUAD_MODE_SHIFT))
#define Counter2_INV_OUT_MASK                   ((uint32)(Counter2_2BIT_MASK        <<  \
                                                                            Counter2_INV_OUT_SHIFT))
#define Counter2_MODE_MASK                      ((uint32)(Counter2_3BIT_MASK        <<  \
                                                                            Counter2_MODE_SHIFT))

/* Shift constants for trigger control register 1 */
#define Counter2_CAPTURE_SHIFT                  (0u)
#define Counter2_COUNT_SHIFT                    (2u)
#define Counter2_RELOAD_SHIFT                   (4u)
#define Counter2_STOP_SHIFT                     (6u)
#define Counter2_START_SHIFT                    (8u)

/* Mask constants for trigger control register 1 */
#define Counter2_CAPTURE_MASK                   ((uint32)(Counter2_2BIT_MASK        <<  \
                                                                  Counter2_CAPTURE_SHIFT))
#define Counter2_COUNT_MASK                     ((uint32)(Counter2_2BIT_MASK        <<  \
                                                                  Counter2_COUNT_SHIFT))
#define Counter2_RELOAD_MASK                    ((uint32)(Counter2_2BIT_MASK        <<  \
                                                                  Counter2_RELOAD_SHIFT))
#define Counter2_STOP_MASK                      ((uint32)(Counter2_2BIT_MASK        <<  \
                                                                  Counter2_STOP_SHIFT))
#define Counter2_START_MASK                     ((uint32)(Counter2_2BIT_MASK        <<  \
                                                                  Counter2_START_SHIFT))

/* MASK */
#define Counter2_1BIT_MASK                      ((uint32)0x01u)
#define Counter2_2BIT_MASK                      ((uint32)0x03u)
#define Counter2_3BIT_MASK                      ((uint32)0x07u)
#define Counter2_6BIT_MASK                      ((uint32)0x3Fu)
#define Counter2_8BIT_MASK                      ((uint32)0xFFu)
#define Counter2_16BIT_MASK                     ((uint32)0xFFFFu)

/* Shift constant for status register */
#define Counter2_RUNNING_STATUS_SHIFT           (30u)


/***************************************
*    Initial Constants
***************************************/

#define Counter2_CTRL_QUAD_BASE_CONFIG                                                          \
        (((uint32)(Counter2_QUAD_ENCODING_MODES     << Counter2_QUAD_MODE_SHIFT))       |\
         ((uint32)(Counter2_CONFIG                  << Counter2_MODE_SHIFT)))

#define Counter2_CTRL_PWM_BASE_CONFIG                                                           \
        (((uint32)(Counter2_PWM_STOP_EVENT          << Counter2_PWM_STOP_KILL_SHIFT))   |\
         ((uint32)(Counter2_PWM_OUT_INVERT          << Counter2_INV_OUT_SHIFT))         |\
         ((uint32)(Counter2_PWM_OUT_N_INVERT        << Counter2_INV_COMPL_OUT_SHIFT))   |\
         ((uint32)(Counter2_PWM_MODE                << Counter2_MODE_SHIFT)))

#define Counter2_CTRL_PWM_RUN_MODE                                                              \
            ((uint32)(Counter2_PWM_RUN_MODE         << Counter2_ONESHOT_SHIFT))
            
#define Counter2_CTRL_PWM_ALIGN                                                                 \
            ((uint32)(Counter2_PWM_ALIGN            << Counter2_UPDOWN_SHIFT))

#define Counter2_CTRL_PWM_KILL_EVENT                                                            \
             ((uint32)(Counter2_PWM_KILL_EVENT      << Counter2_PWM_SYNC_KILL_SHIFT))

#define Counter2_CTRL_PWM_DEAD_TIME_CYCLE                                                       \
            ((uint32)(Counter2_PWM_DEAD_TIME_CYCLE  << Counter2_PRESCALER_SHIFT))

#define Counter2_CTRL_PWM_PRESCALER                                                             \
            ((uint32)(Counter2_PWM_PRESCALER        << Counter2_PRESCALER_SHIFT))

#define Counter2_CTRL_TIMER_BASE_CONFIG                                                         \
        (((uint32)(Counter2_TC_PRESCALER            << Counter2_PRESCALER_SHIFT))       |\
         ((uint32)(Counter2_TC_COUNTER_MODE         << Counter2_UPDOWN_SHIFT))          |\
         ((uint32)(Counter2_TC_RUN_MODE             << Counter2_ONESHOT_SHIFT))         |\
         ((uint32)(Counter2_TC_COMP_CAP_MODE        << Counter2_MODE_SHIFT)))
        
#define Counter2_QUAD_SIGNALS_MODES                                                             \
        (((uint32)(Counter2_QUAD_PHIA_SIGNAL_MODE   << Counter2_COUNT_SHIFT))           |\
         ((uint32)(Counter2_QUAD_INDEX_SIGNAL_MODE  << Counter2_RELOAD_SHIFT))          |\
         ((uint32)(Counter2_QUAD_STOP_SIGNAL_MODE   << Counter2_STOP_SHIFT))            |\
         ((uint32)(Counter2_QUAD_PHIB_SIGNAL_MODE   << Counter2_START_SHIFT)))

#define Counter2_PWM_SIGNALS_MODES                                                              \
        (((uint32)(Counter2_PWM_SWITCH_SIGNAL_MODE  << Counter2_CAPTURE_SHIFT))         |\
         ((uint32)(Counter2_PWM_COUNT_SIGNAL_MODE   << Counter2_COUNT_SHIFT))           |\
         ((uint32)(Counter2_PWM_RELOAD_SIGNAL_MODE  << Counter2_RELOAD_SHIFT))          |\
         ((uint32)(Counter2_PWM_STOP_SIGNAL_MODE    << Counter2_STOP_SHIFT))            |\
         ((uint32)(Counter2_PWM_START_SIGNAL_MODE   << Counter2_START_SHIFT)))

#define Counter2_TIMER_SIGNALS_MODES                                                            \
        (((uint32)(Counter2_TC_CAPTURE_SIGNAL_MODE  << Counter2_CAPTURE_SHIFT))         |\
         ((uint32)(Counter2_TC_COUNT_SIGNAL_MODE    << Counter2_COUNT_SHIFT))           |\
         ((uint32)(Counter2_TC_RELOAD_SIGNAL_MODE   << Counter2_RELOAD_SHIFT))          |\
         ((uint32)(Counter2_TC_STOP_SIGNAL_MODE     << Counter2_STOP_SHIFT))            |\
         ((uint32)(Counter2_TC_START_SIGNAL_MODE    << Counter2_START_SHIFT)))
        
#define Counter2_TIMER_UPDOWN_CNT_USED                                                          \
                ((Counter2__COUNT_UPDOWN0 == Counter2_TC_COUNTER_MODE)                  ||\
                 (Counter2__COUNT_UPDOWN1 == Counter2_TC_COUNTER_MODE))

#define Counter2_PWM_UPDOWN_CNT_USED                                                            \
                ((Counter2__CENTER == Counter2_PWM_ALIGN)                               ||\
                 (Counter2__ASYMMETRIC == Counter2_PWM_ALIGN))               
        
#define Counter2_PWM_PR_INIT_VALUE              (1u)
#define Counter2_QUAD_PERIOD_INIT_VALUE         (0x8000u)



#endif /* End CY_TCPWM_Counter2_H */

/* [] END OF FILE */
