/*******************************************************************************
* File Name: Counter2_PM.c
* Version 2.10
*
* Description:
*  This file contains the setup, control, and status commands to support
*  the component operations in the low power mode.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "Counter2.h"

static Counter2_BACKUP_STRUCT Counter2_backup;


/*******************************************************************************
* Function Name: Counter2_SaveConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to save here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_SaveConfig(void)
{

}


/*******************************************************************************
* Function Name: Counter2_Sleep
********************************************************************************
*
* Summary:
*  Stops the component operation and saves the user configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_Sleep(void)
{
    if(0u != (Counter2_BLOCK_CONTROL_REG & Counter2_MASK))
    {
        Counter2_backup.enableState = 1u;
    }
    else
    {
        Counter2_backup.enableState = 0u;
    }

    Counter2_Stop();
    Counter2_SaveConfig();
}


/*******************************************************************************
* Function Name: Counter2_RestoreConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to restore here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_RestoreConfig(void)
{

}


/*******************************************************************************
* Function Name: Counter2_Wakeup
********************************************************************************
*
* Summary:
*  Restores the user configuration and restores the enable state.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Counter2_Wakeup(void)
{
    Counter2_RestoreConfig();

    if(0u != Counter2_backup.enableState)
    {
        Counter2_Enable();
    }
}


/* [] END OF FILE */
