/*******************************************************************************
* File Name: Counter3.h
* Version 2.10
*
* Description:
*  This file provides constants and parameter values for the Counter3
*  component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_TCPWM_Counter3_H)
#define CY_TCPWM_Counter3_H


#include "CyLib.h"
#include "cytypes.h"
#include "cyfitter.h"


/*******************************************************************************
* Internal Type defines
*******************************************************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} Counter3_BACKUP_STRUCT;


/*******************************************************************************
* Variables
*******************************************************************************/
extern uint8  Counter3_initVar;


/***************************************
*   Conditional Compilation Parameters
****************************************/

#define Counter3_CY_TCPWM_V2                    (CYIPBLOCK_m0s8tcpwm_VERSION == 2u)
#define Counter3_CY_TCPWM_4000                  (CY_PSOC4_4000)

/* TCPWM Configuration */
#define Counter3_CONFIG                         (7lu)

/* Quad Mode */
/* Parameters */
#define Counter3_QUAD_ENCODING_MODES            (0lu)
#define Counter3_QUAD_AUTO_START                (1lu)

/* Signal modes */
#define Counter3_QUAD_INDEX_SIGNAL_MODE         (0lu)
#define Counter3_QUAD_PHIA_SIGNAL_MODE          (3lu)
#define Counter3_QUAD_PHIB_SIGNAL_MODE          (3lu)
#define Counter3_QUAD_STOP_SIGNAL_MODE          (0lu)

/* Signal present */
#define Counter3_QUAD_INDEX_SIGNAL_PRESENT      (0lu)
#define Counter3_QUAD_STOP_SIGNAL_PRESENT       (0lu)

/* Interrupt Mask */
#define Counter3_QUAD_INTERRUPT_MASK            (1lu)

/* Timer/Counter Mode */
/* Parameters */
#define Counter3_TC_RUN_MODE                    (0lu)
#define Counter3_TC_COUNTER_MODE                (0lu)
#define Counter3_TC_COMP_CAP_MODE               (2lu)
#define Counter3_TC_PRESCALER                   (0lu)

/* Signal modes */
#define Counter3_TC_RELOAD_SIGNAL_MODE          (0lu)
#define Counter3_TC_COUNT_SIGNAL_MODE           (3lu)
#define Counter3_TC_START_SIGNAL_MODE           (0lu)
#define Counter3_TC_STOP_SIGNAL_MODE            (0lu)
#define Counter3_TC_CAPTURE_SIGNAL_MODE         (0lu)

/* Signal present */
#define Counter3_TC_RELOAD_SIGNAL_PRESENT       (0lu)
#define Counter3_TC_COUNT_SIGNAL_PRESENT        (0lu)
#define Counter3_TC_START_SIGNAL_PRESENT        (0lu)
#define Counter3_TC_STOP_SIGNAL_PRESENT         (0lu)
#define Counter3_TC_CAPTURE_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define Counter3_TC_INTERRUPT_MASK              (1lu)

/* PWM Mode */
/* Parameters */
#define Counter3_PWM_KILL_EVENT                 (0lu)
#define Counter3_PWM_STOP_EVENT                 (0lu)
#define Counter3_PWM_MODE                       (4lu)
#define Counter3_PWM_OUT_N_INVERT               (0lu)
#define Counter3_PWM_OUT_INVERT                 (0lu)
#define Counter3_PWM_ALIGN                      (0lu)
#define Counter3_PWM_RUN_MODE                   (0lu)
#define Counter3_PWM_DEAD_TIME_CYCLE            (0lu)
#define Counter3_PWM_PRESCALER                  (0lu)

/* Signal modes */
#define Counter3_PWM_RELOAD_SIGNAL_MODE         (0lu)
#define Counter3_PWM_COUNT_SIGNAL_MODE          (0lu)
#define Counter3_PWM_START_SIGNAL_MODE          (0lu)
#define Counter3_PWM_STOP_SIGNAL_MODE           (0lu)
#define Counter3_PWM_SWITCH_SIGNAL_MODE         (0lu)

/* Signal present */
#define Counter3_PWM_RELOAD_SIGNAL_PRESENT      (0lu)
#define Counter3_PWM_COUNT_SIGNAL_PRESENT       (1lu)
#define Counter3_PWM_START_SIGNAL_PRESENT       (1lu)
#define Counter3_PWM_STOP_SIGNAL_PRESENT        (1lu)
#define Counter3_PWM_SWITCH_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define Counter3_PWM_INTERRUPT_MASK             (0lu)


/***************************************
*    Initial Parameter Constants
***************************************/

/* Timer/Counter Mode */
#define Counter3_TC_PERIOD_VALUE                (65535lu)
#define Counter3_TC_COMPARE_VALUE               (65535lu)
#define Counter3_TC_COMPARE_BUF_VALUE           (65535lu)
#define Counter3_TC_COMPARE_SWAP                (0lu)

/* PWM Mode */
#define Counter3_PWM_PERIOD_VALUE               (10000lu)
#define Counter3_PWM_PERIOD_BUF_VALUE           (65535lu)
#define Counter3_PWM_PERIOD_SWAP                (0lu)
#define Counter3_PWM_COMPARE_VALUE              (5000lu)
#define Counter3_PWM_COMPARE_BUF_VALUE          (65535lu)
#define Counter3_PWM_COMPARE_SWAP               (0lu)


/***************************************
*    Enumerated Types and Parameters
***************************************/

#define Counter3__LEFT 0
#define Counter3__RIGHT 1
#define Counter3__CENTER 2
#define Counter3__ASYMMETRIC 3

#define Counter3__X1 0
#define Counter3__X2 1
#define Counter3__X4 2

#define Counter3__PWM 4
#define Counter3__PWM_DT 5
#define Counter3__PWM_PR 6

#define Counter3__INVERSE 1
#define Counter3__DIRECT 0

#define Counter3__CAPTURE 2
#define Counter3__COMPARE 0

#define Counter3__TRIG_LEVEL 3
#define Counter3__TRIG_RISING 0
#define Counter3__TRIG_FALLING 1
#define Counter3__TRIG_BOTH 2

#define Counter3__INTR_MASK_TC 1
#define Counter3__INTR_MASK_CC_MATCH 2
#define Counter3__INTR_MASK_NONE 0
#define Counter3__INTR_MASK_TC_CC 3

#define Counter3__UNCONFIG 8
#define Counter3__TIMER 1
#define Counter3__QUAD 3
#define Counter3__PWM_SEL 7

#define Counter3__COUNT_UP 0
#define Counter3__COUNT_DOWN 1
#define Counter3__COUNT_UPDOWN0 2
#define Counter3__COUNT_UPDOWN1 3


/* Prescaler */
#define Counter3_PRESCALE_DIVBY1                ((uint32)(0u << Counter3_PRESCALER_SHIFT))
#define Counter3_PRESCALE_DIVBY2                ((uint32)(1u << Counter3_PRESCALER_SHIFT))
#define Counter3_PRESCALE_DIVBY4                ((uint32)(2u << Counter3_PRESCALER_SHIFT))
#define Counter3_PRESCALE_DIVBY8                ((uint32)(3u << Counter3_PRESCALER_SHIFT))
#define Counter3_PRESCALE_DIVBY16               ((uint32)(4u << Counter3_PRESCALER_SHIFT))
#define Counter3_PRESCALE_DIVBY32               ((uint32)(5u << Counter3_PRESCALER_SHIFT))
#define Counter3_PRESCALE_DIVBY64               ((uint32)(6u << Counter3_PRESCALER_SHIFT))
#define Counter3_PRESCALE_DIVBY128              ((uint32)(7u << Counter3_PRESCALER_SHIFT))

/* TCPWM set modes */
#define Counter3_MODE_TIMER_COMPARE             ((uint32)(Counter3__COMPARE         <<  \
                                                                  Counter3_MODE_SHIFT))
#define Counter3_MODE_TIMER_CAPTURE             ((uint32)(Counter3__CAPTURE         <<  \
                                                                  Counter3_MODE_SHIFT))
#define Counter3_MODE_QUAD                      ((uint32)(Counter3__QUAD            <<  \
                                                                  Counter3_MODE_SHIFT))
#define Counter3_MODE_PWM                       ((uint32)(Counter3__PWM             <<  \
                                                                  Counter3_MODE_SHIFT))
#define Counter3_MODE_PWM_DT                    ((uint32)(Counter3__PWM_DT          <<  \
                                                                  Counter3_MODE_SHIFT))
#define Counter3_MODE_PWM_PR                    ((uint32)(Counter3__PWM_PR          <<  \
                                                                  Counter3_MODE_SHIFT))

/* Quad Modes */
#define Counter3_MODE_X1                        ((uint32)(Counter3__X1              <<  \
                                                                  Counter3_QUAD_MODE_SHIFT))
#define Counter3_MODE_X2                        ((uint32)(Counter3__X2              <<  \
                                                                  Counter3_QUAD_MODE_SHIFT))
#define Counter3_MODE_X4                        ((uint32)(Counter3__X4              <<  \
                                                                  Counter3_QUAD_MODE_SHIFT))

/* Counter modes */
#define Counter3_COUNT_UP                       ((uint32)(Counter3__COUNT_UP        <<  \
                                                                  Counter3_UPDOWN_SHIFT))
#define Counter3_COUNT_DOWN                     ((uint32)(Counter3__COUNT_DOWN      <<  \
                                                                  Counter3_UPDOWN_SHIFT))
#define Counter3_COUNT_UPDOWN0                  ((uint32)(Counter3__COUNT_UPDOWN0   <<  \
                                                                  Counter3_UPDOWN_SHIFT))
#define Counter3_COUNT_UPDOWN1                  ((uint32)(Counter3__COUNT_UPDOWN1   <<  \
                                                                  Counter3_UPDOWN_SHIFT))

/* PWM output invert */
#define Counter3_INVERT_LINE                    ((uint32)(Counter3__INVERSE         <<  \
                                                                  Counter3_INV_OUT_SHIFT))
#define Counter3_INVERT_LINE_N                  ((uint32)(Counter3__INVERSE         <<  \
                                                                  Counter3_INV_COMPL_OUT_SHIFT))

/* Trigger modes */
#define Counter3_TRIG_RISING                    ((uint32)Counter3__TRIG_RISING)
#define Counter3_TRIG_FALLING                   ((uint32)Counter3__TRIG_FALLING)
#define Counter3_TRIG_BOTH                      ((uint32)Counter3__TRIG_BOTH)
#define Counter3_TRIG_LEVEL                     ((uint32)Counter3__TRIG_LEVEL)

/* Interrupt mask */
#define Counter3_INTR_MASK_TC                   ((uint32)Counter3__INTR_MASK_TC)
#define Counter3_INTR_MASK_CC_MATCH             ((uint32)Counter3__INTR_MASK_CC_MATCH)

/* PWM Output Controls */
#define Counter3_CC_MATCH_SET                   (0x00u)
#define Counter3_CC_MATCH_CLEAR                 (0x01u)
#define Counter3_CC_MATCH_INVERT                (0x02u)
#define Counter3_CC_MATCH_NO_CHANGE             (0x03u)
#define Counter3_OVERLOW_SET                    (0x00u)
#define Counter3_OVERLOW_CLEAR                  (0x04u)
#define Counter3_OVERLOW_INVERT                 (0x08u)
#define Counter3_OVERLOW_NO_CHANGE              (0x0Cu)
#define Counter3_UNDERFLOW_SET                  (0x00u)
#define Counter3_UNDERFLOW_CLEAR                (0x10u)
#define Counter3_UNDERFLOW_INVERT               (0x20u)
#define Counter3_UNDERFLOW_NO_CHANGE            (0x30u)

/* PWM Align */
#define Counter3_PWM_MODE_LEFT                  (Counter3_CC_MATCH_CLEAR        |   \
                                                         Counter3_OVERLOW_SET           |   \
                                                         Counter3_UNDERFLOW_NO_CHANGE)
#define Counter3_PWM_MODE_RIGHT                 (Counter3_CC_MATCH_SET          |   \
                                                         Counter3_OVERLOW_NO_CHANGE     |   \
                                                         Counter3_UNDERFLOW_CLEAR)
#define Counter3_PWM_MODE_ASYM                  (Counter3_CC_MATCH_INVERT       |   \
                                                         Counter3_OVERLOW_SET           |   \
                                                         Counter3_UNDERFLOW_CLEAR)

#if (Counter3_CY_TCPWM_V2)
    #if(Counter3_CY_TCPWM_4000)
        #define Counter3_PWM_MODE_CENTER                (Counter3_CC_MATCH_INVERT       |   \
                                                                 Counter3_OVERLOW_NO_CHANGE     |   \
                                                                 Counter3_UNDERFLOW_CLEAR)
    #else
        #define Counter3_PWM_MODE_CENTER                (Counter3_CC_MATCH_INVERT       |   \
                                                                 Counter3_OVERLOW_SET           |   \
                                                                 Counter3_UNDERFLOW_CLEAR)
    #endif /* (Counter3_CY_TCPWM_4000) */
#else
    #define Counter3_PWM_MODE_CENTER                (Counter3_CC_MATCH_INVERT       |   \
                                                             Counter3_OVERLOW_NO_CHANGE     |   \
                                                             Counter3_UNDERFLOW_CLEAR)
#endif /* (Counter3_CY_TCPWM_NEW) */

/* Command operations without condition */
#define Counter3_CMD_CAPTURE                    (0u)
#define Counter3_CMD_RELOAD                     (8u)
#define Counter3_CMD_STOP                       (16u)
#define Counter3_CMD_START                      (24u)

/* Status */
#define Counter3_STATUS_DOWN                    (1u)
#define Counter3_STATUS_RUNNING                 (2u)


/***************************************
*        Function Prototypes
****************************************/

void   Counter3_Init(void);
void   Counter3_Enable(void);
void   Counter3_Start(void);
void   Counter3_Stop(void);

void   Counter3_SetMode(uint32 mode);
void   Counter3_SetCounterMode(uint32 counterMode);
void   Counter3_SetPWMMode(uint32 modeMask);
void   Counter3_SetQDMode(uint32 qdMode);

void   Counter3_SetPrescaler(uint32 prescaler);
void   Counter3_TriggerCommand(uint32 mask, uint32 command);
void   Counter3_SetOneShot(uint32 oneShotEnable);
uint32 Counter3_ReadStatus(void);

void   Counter3_SetPWMSyncKill(uint32 syncKillEnable);
void   Counter3_SetPWMStopOnKill(uint32 stopOnKillEnable);
void   Counter3_SetPWMDeadTime(uint32 deadTime);
void   Counter3_SetPWMInvert(uint32 mask);

void   Counter3_SetInterruptMode(uint32 interruptMask);
uint32 Counter3_GetInterruptSourceMasked(void);
uint32 Counter3_GetInterruptSource(void);
void   Counter3_ClearInterrupt(uint32 interruptMask);
void   Counter3_SetInterrupt(uint32 interruptMask);

void   Counter3_WriteCounter(uint32 count);
uint32 Counter3_ReadCounter(void);

uint32 Counter3_ReadCapture(void);
uint32 Counter3_ReadCaptureBuf(void);

void   Counter3_WritePeriod(uint32 period);
uint32 Counter3_ReadPeriod(void);
void   Counter3_WritePeriodBuf(uint32 periodBuf);
uint32 Counter3_ReadPeriodBuf(void);

void   Counter3_WriteCompare(uint32 compare);
uint32 Counter3_ReadCompare(void);
void   Counter3_WriteCompareBuf(uint32 compareBuf);
uint32 Counter3_ReadCompareBuf(void);

void   Counter3_SetPeriodSwap(uint32 swapEnable);
void   Counter3_SetCompareSwap(uint32 swapEnable);

void   Counter3_SetCaptureMode(uint32 triggerMode);
void   Counter3_SetReloadMode(uint32 triggerMode);
void   Counter3_SetStartMode(uint32 triggerMode);
void   Counter3_SetStopMode(uint32 triggerMode);
void   Counter3_SetCountMode(uint32 triggerMode);

void   Counter3_SaveConfig(void);
void   Counter3_RestoreConfig(void);
void   Counter3_Sleep(void);
void   Counter3_Wakeup(void);


/***************************************
*             Registers
***************************************/

#define Counter3_BLOCK_CONTROL_REG              (*(reg32 *) Counter3_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define Counter3_BLOCK_CONTROL_PTR              ( (reg32 *) Counter3_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define Counter3_COMMAND_REG                    (*(reg32 *) Counter3_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define Counter3_COMMAND_PTR                    ( (reg32 *) Counter3_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define Counter3_INTRRUPT_CAUSE_REG             (*(reg32 *) Counter3_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define Counter3_INTRRUPT_CAUSE_PTR             ( (reg32 *) Counter3_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define Counter3_CONTROL_REG                    (*(reg32 *) Counter3_cy_m0s8_tcpwm_1__CTRL )
#define Counter3_CONTROL_PTR                    ( (reg32 *) Counter3_cy_m0s8_tcpwm_1__CTRL )
#define Counter3_STATUS_REG                     (*(reg32 *) Counter3_cy_m0s8_tcpwm_1__STATUS )
#define Counter3_STATUS_PTR                     ( (reg32 *) Counter3_cy_m0s8_tcpwm_1__STATUS )
#define Counter3_COUNTER_REG                    (*(reg32 *) Counter3_cy_m0s8_tcpwm_1__COUNTER )
#define Counter3_COUNTER_PTR                    ( (reg32 *) Counter3_cy_m0s8_tcpwm_1__COUNTER )
#define Counter3_COMP_CAP_REG                   (*(reg32 *) Counter3_cy_m0s8_tcpwm_1__CC )
#define Counter3_COMP_CAP_PTR                   ( (reg32 *) Counter3_cy_m0s8_tcpwm_1__CC )
#define Counter3_COMP_CAP_BUF_REG               (*(reg32 *) Counter3_cy_m0s8_tcpwm_1__CC_BUFF )
#define Counter3_COMP_CAP_BUF_PTR               ( (reg32 *) Counter3_cy_m0s8_tcpwm_1__CC_BUFF )
#define Counter3_PERIOD_REG                     (*(reg32 *) Counter3_cy_m0s8_tcpwm_1__PERIOD )
#define Counter3_PERIOD_PTR                     ( (reg32 *) Counter3_cy_m0s8_tcpwm_1__PERIOD )
#define Counter3_PERIOD_BUF_REG                 (*(reg32 *) Counter3_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define Counter3_PERIOD_BUF_PTR                 ( (reg32 *) Counter3_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define Counter3_TRIG_CONTROL0_REG              (*(reg32 *) Counter3_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define Counter3_TRIG_CONTROL0_PTR              ( (reg32 *) Counter3_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define Counter3_TRIG_CONTROL1_REG              (*(reg32 *) Counter3_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define Counter3_TRIG_CONTROL1_PTR              ( (reg32 *) Counter3_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define Counter3_TRIG_CONTROL2_REG              (*(reg32 *) Counter3_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define Counter3_TRIG_CONTROL2_PTR              ( (reg32 *) Counter3_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define Counter3_INTERRUPT_REQ_REG              (*(reg32 *) Counter3_cy_m0s8_tcpwm_1__INTR )
#define Counter3_INTERRUPT_REQ_PTR              ( (reg32 *) Counter3_cy_m0s8_tcpwm_1__INTR )
#define Counter3_INTERRUPT_SET_REG              (*(reg32 *) Counter3_cy_m0s8_tcpwm_1__INTR_SET )
#define Counter3_INTERRUPT_SET_PTR              ( (reg32 *) Counter3_cy_m0s8_tcpwm_1__INTR_SET )
#define Counter3_INTERRUPT_MASK_REG             (*(reg32 *) Counter3_cy_m0s8_tcpwm_1__INTR_MASK )
#define Counter3_INTERRUPT_MASK_PTR             ( (reg32 *) Counter3_cy_m0s8_tcpwm_1__INTR_MASK )
#define Counter3_INTERRUPT_MASKED_REG           (*(reg32 *) Counter3_cy_m0s8_tcpwm_1__INTR_MASKED )
#define Counter3_INTERRUPT_MASKED_PTR           ( (reg32 *) Counter3_cy_m0s8_tcpwm_1__INTR_MASKED )


/***************************************
*       Registers Constants
***************************************/

/* Mask */
#define Counter3_MASK                           ((uint32)Counter3_cy_m0s8_tcpwm_1__TCPWM_CTRL_MASK)

/* Shift constants for control register */
#define Counter3_RELOAD_CC_SHIFT                (0u)
#define Counter3_RELOAD_PERIOD_SHIFT            (1u)
#define Counter3_PWM_SYNC_KILL_SHIFT            (2u)
#define Counter3_PWM_STOP_KILL_SHIFT            (3u)
#define Counter3_PRESCALER_SHIFT                (8u)
#define Counter3_UPDOWN_SHIFT                   (16u)
#define Counter3_ONESHOT_SHIFT                  (18u)
#define Counter3_QUAD_MODE_SHIFT                (20u)
#define Counter3_INV_OUT_SHIFT                  (20u)
#define Counter3_INV_COMPL_OUT_SHIFT            (21u)
#define Counter3_MODE_SHIFT                     (24u)

/* Mask constants for control register */
#define Counter3_RELOAD_CC_MASK                 ((uint32)(Counter3_1BIT_MASK        <<  \
                                                                            Counter3_RELOAD_CC_SHIFT))
#define Counter3_RELOAD_PERIOD_MASK             ((uint32)(Counter3_1BIT_MASK        <<  \
                                                                            Counter3_RELOAD_PERIOD_SHIFT))
#define Counter3_PWM_SYNC_KILL_MASK             ((uint32)(Counter3_1BIT_MASK        <<  \
                                                                            Counter3_PWM_SYNC_KILL_SHIFT))
#define Counter3_PWM_STOP_KILL_MASK             ((uint32)(Counter3_1BIT_MASK        <<  \
                                                                            Counter3_PWM_STOP_KILL_SHIFT))
#define Counter3_PRESCALER_MASK                 ((uint32)(Counter3_8BIT_MASK        <<  \
                                                                            Counter3_PRESCALER_SHIFT))
#define Counter3_UPDOWN_MASK                    ((uint32)(Counter3_2BIT_MASK        <<  \
                                                                            Counter3_UPDOWN_SHIFT))
#define Counter3_ONESHOT_MASK                   ((uint32)(Counter3_1BIT_MASK        <<  \
                                                                            Counter3_ONESHOT_SHIFT))
#define Counter3_QUAD_MODE_MASK                 ((uint32)(Counter3_3BIT_MASK        <<  \
                                                                            Counter3_QUAD_MODE_SHIFT))
#define Counter3_INV_OUT_MASK                   ((uint32)(Counter3_2BIT_MASK        <<  \
                                                                            Counter3_INV_OUT_SHIFT))
#define Counter3_MODE_MASK                      ((uint32)(Counter3_3BIT_MASK        <<  \
                                                                            Counter3_MODE_SHIFT))

/* Shift constants for trigger control register 1 */
#define Counter3_CAPTURE_SHIFT                  (0u)
#define Counter3_COUNT_SHIFT                    (2u)
#define Counter3_RELOAD_SHIFT                   (4u)
#define Counter3_STOP_SHIFT                     (6u)
#define Counter3_START_SHIFT                    (8u)

/* Mask constants for trigger control register 1 */
#define Counter3_CAPTURE_MASK                   ((uint32)(Counter3_2BIT_MASK        <<  \
                                                                  Counter3_CAPTURE_SHIFT))
#define Counter3_COUNT_MASK                     ((uint32)(Counter3_2BIT_MASK        <<  \
                                                                  Counter3_COUNT_SHIFT))
#define Counter3_RELOAD_MASK                    ((uint32)(Counter3_2BIT_MASK        <<  \
                                                                  Counter3_RELOAD_SHIFT))
#define Counter3_STOP_MASK                      ((uint32)(Counter3_2BIT_MASK        <<  \
                                                                  Counter3_STOP_SHIFT))
#define Counter3_START_MASK                     ((uint32)(Counter3_2BIT_MASK        <<  \
                                                                  Counter3_START_SHIFT))

/* MASK */
#define Counter3_1BIT_MASK                      ((uint32)0x01u)
#define Counter3_2BIT_MASK                      ((uint32)0x03u)
#define Counter3_3BIT_MASK                      ((uint32)0x07u)
#define Counter3_6BIT_MASK                      ((uint32)0x3Fu)
#define Counter3_8BIT_MASK                      ((uint32)0xFFu)
#define Counter3_16BIT_MASK                     ((uint32)0xFFFFu)

/* Shift constant for status register */
#define Counter3_RUNNING_STATUS_SHIFT           (30u)


/***************************************
*    Initial Constants
***************************************/

#define Counter3_CTRL_QUAD_BASE_CONFIG                                                          \
        (((uint32)(Counter3_QUAD_ENCODING_MODES     << Counter3_QUAD_MODE_SHIFT))       |\
         ((uint32)(Counter3_CONFIG                  << Counter3_MODE_SHIFT)))

#define Counter3_CTRL_PWM_BASE_CONFIG                                                           \
        (((uint32)(Counter3_PWM_STOP_EVENT          << Counter3_PWM_STOP_KILL_SHIFT))   |\
         ((uint32)(Counter3_PWM_OUT_INVERT          << Counter3_INV_OUT_SHIFT))         |\
         ((uint32)(Counter3_PWM_OUT_N_INVERT        << Counter3_INV_COMPL_OUT_SHIFT))   |\
         ((uint32)(Counter3_PWM_MODE                << Counter3_MODE_SHIFT)))

#define Counter3_CTRL_PWM_RUN_MODE                                                              \
            ((uint32)(Counter3_PWM_RUN_MODE         << Counter3_ONESHOT_SHIFT))
            
#define Counter3_CTRL_PWM_ALIGN                                                                 \
            ((uint32)(Counter3_PWM_ALIGN            << Counter3_UPDOWN_SHIFT))

#define Counter3_CTRL_PWM_KILL_EVENT                                                            \
             ((uint32)(Counter3_PWM_KILL_EVENT      << Counter3_PWM_SYNC_KILL_SHIFT))

#define Counter3_CTRL_PWM_DEAD_TIME_CYCLE                                                       \
            ((uint32)(Counter3_PWM_DEAD_TIME_CYCLE  << Counter3_PRESCALER_SHIFT))

#define Counter3_CTRL_PWM_PRESCALER                                                             \
            ((uint32)(Counter3_PWM_PRESCALER        << Counter3_PRESCALER_SHIFT))

#define Counter3_CTRL_TIMER_BASE_CONFIG                                                         \
        (((uint32)(Counter3_TC_PRESCALER            << Counter3_PRESCALER_SHIFT))       |\
         ((uint32)(Counter3_TC_COUNTER_MODE         << Counter3_UPDOWN_SHIFT))          |\
         ((uint32)(Counter3_TC_RUN_MODE             << Counter3_ONESHOT_SHIFT))         |\
         ((uint32)(Counter3_TC_COMP_CAP_MODE        << Counter3_MODE_SHIFT)))
        
#define Counter3_QUAD_SIGNALS_MODES                                                             \
        (((uint32)(Counter3_QUAD_PHIA_SIGNAL_MODE   << Counter3_COUNT_SHIFT))           |\
         ((uint32)(Counter3_QUAD_INDEX_SIGNAL_MODE  << Counter3_RELOAD_SHIFT))          |\
         ((uint32)(Counter3_QUAD_STOP_SIGNAL_MODE   << Counter3_STOP_SHIFT))            |\
         ((uint32)(Counter3_QUAD_PHIB_SIGNAL_MODE   << Counter3_START_SHIFT)))

#define Counter3_PWM_SIGNALS_MODES                                                              \
        (((uint32)(Counter3_PWM_SWITCH_SIGNAL_MODE  << Counter3_CAPTURE_SHIFT))         |\
         ((uint32)(Counter3_PWM_COUNT_SIGNAL_MODE   << Counter3_COUNT_SHIFT))           |\
         ((uint32)(Counter3_PWM_RELOAD_SIGNAL_MODE  << Counter3_RELOAD_SHIFT))          |\
         ((uint32)(Counter3_PWM_STOP_SIGNAL_MODE    << Counter3_STOP_SHIFT))            |\
         ((uint32)(Counter3_PWM_START_SIGNAL_MODE   << Counter3_START_SHIFT)))

#define Counter3_TIMER_SIGNALS_MODES                                                            \
        (((uint32)(Counter3_TC_CAPTURE_SIGNAL_MODE  << Counter3_CAPTURE_SHIFT))         |\
         ((uint32)(Counter3_TC_COUNT_SIGNAL_MODE    << Counter3_COUNT_SHIFT))           |\
         ((uint32)(Counter3_TC_RELOAD_SIGNAL_MODE   << Counter3_RELOAD_SHIFT))          |\
         ((uint32)(Counter3_TC_STOP_SIGNAL_MODE     << Counter3_STOP_SHIFT))            |\
         ((uint32)(Counter3_TC_START_SIGNAL_MODE    << Counter3_START_SHIFT)))
        
#define Counter3_TIMER_UPDOWN_CNT_USED                                                          \
                ((Counter3__COUNT_UPDOWN0 == Counter3_TC_COUNTER_MODE)                  ||\
                 (Counter3__COUNT_UPDOWN1 == Counter3_TC_COUNTER_MODE))

#define Counter3_PWM_UPDOWN_CNT_USED                                                            \
                ((Counter3__CENTER == Counter3_PWM_ALIGN)                               ||\
                 (Counter3__ASYMMETRIC == Counter3_PWM_ALIGN))               
        
#define Counter3_PWM_PR_INIT_VALUE              (1u)
#define Counter3_QUAD_PERIOD_INIT_VALUE         (0x8000u)



#endif /* End CY_TCPWM_Counter3_H */

/* [] END OF FILE */
