/*******************************************************************************
* File Name: Counter3_PM.c
* Version 2.10
*
* Description:
*  This file contains the setup, control, and status commands to support
*  the component operations in the low power mode.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "Counter3.h"

static Counter3_BACKUP_STRUCT Counter3_backup;


/*******************************************************************************
* Function Name: Counter3_SaveConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to save here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Counter3_SaveConfig(void)
{

}


/*******************************************************************************
* Function Name: Counter3_Sleep
********************************************************************************
*
* Summary:
*  Stops the component operation and saves the user configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Counter3_Sleep(void)
{
    if(0u != (Counter3_BLOCK_CONTROL_REG & Counter3_MASK))
    {
        Counter3_backup.enableState = 1u;
    }
    else
    {
        Counter3_backup.enableState = 0u;
    }

    Counter3_Stop();
    Counter3_SaveConfig();
}


/*******************************************************************************
* Function Name: Counter3_RestoreConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to restore here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Counter3_RestoreConfig(void)
{

}


/*******************************************************************************
* Function Name: Counter3_Wakeup
********************************************************************************
*
* Summary:
*  Restores the user configuration and restores the enable state.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Counter3_Wakeup(void)
{
    Counter3_RestoreConfig();

    if(0u != Counter3_backup.enableState)
    {
        Counter3_Enable();
    }
}


/* [] END OF FILE */
