#include "project.h"
#include "stdio.h"
#include "string.h"
#include "tty_utils.h"
#include "em_EEPROM_utils.h"
#include "cmd_func.h"

cmd_func_type g_cmd_list[] = {
    {"help",    do_help,    "Show help message"},
    {"list",    do_list,    "list current settings"},
    {"save",    do_save,    "save counter settings to Em_EEPROM"}, 
    {"load",    do_load,    "load counter settings from Em_EEPROM"},
    {"erase",   do_erase,   "erase Em_EEPROM"},
    {"stop",    do_stop,    "stop   x : stop  the counter x"},
    {"start",   do_start,   "start  x : start the counter x"},
    {"period",  do_period,  "period x : set period of counter x"},
    {"compare", do_compare, "compre x : set compare of counter x"},
    {0, 0, 0} // all 0, end of record list
} ;

func_ptr_type get_func(char *cmd) 
{
    int i = 0 ;
    
    for (i = 0 ; g_cmd_list[i].cmd ; i++ ) {
        if (strncmp(g_cmd_list[i].cmd, cmd, strlen(g_cmd_list[i].cmd)) == 0) {
            break ;
        }
    }
    return(g_cmd_list[i].func) ;
}

void do_help(char *arg) 
{
    (void) arg ;
    int i ;
    print("=== help / usage ===\r\n") ;
    for (i = 0 ; g_cmd_list[i].cmd ; i++ ) {
        print(g_cmd_list[i].cmd) ;
        print(": ") ;
        print(g_cmd_list[i].description) ;
        print("\r\n") ;
    }
    print("x can be 1 for counter1, 2 for counter2, 4 for counter 3\r\n") ;
    print("for all counters use 7, which is 1 + 2 + 4\r\n") ;
}

void do_list(char *arg) 
{
    (void) arg ;
    int i ;
    print("=== Counter Settings ===\r\n") ;
    print("No: Period,  Compare, Status\r\n") ;
    counter[0].period  = Counter1_ReadPeriod() ;
    counter[0].compare = Counter1_ReadCompare()  ;
    counter[1].period  = Counter2_ReadPeriod() ;
    counter[1].compare = Counter2_ReadCompare()  ;
    counter[2].period  = Counter3_ReadPeriod() ;
    counter[2].compare = Counter3_ReadCompare()  ;
    for (i = 0 ; i < NUM_COUNTER ; i++ ) {
        sprintf(str, "%d : %d, %d ", 
            i+1, counter[i].period + 1, counter[i].compare + 1) ;
        print(str) ;
        if (counter[i].status == COUNTER_RUNNING) {
            print("Running\r\n") ;
        } else {
            print("Stopped\r\n") ;
        }
    }  
}

void do_save(char *arg) 
{
    (void) arg ;
    cy_en_em_eeprom_status_t result ;
    result = save_pwm() ;
    if (result == CY_EM_EEPROM_SUCCESS) {
        print("Saved\r\n") ;
    } else {
        print_em_eprom_error(result) ;        
    }
}

void do_load(char *arg) 
{
    (void)arg ;
    load_pwm() ;
}

void do_erase(char *arg)
{
    (void)arg ;
    cy_en_em_eeprom_status_t result ;
    print("Erase Em_EEPROM? (Yes/No) ") ;
    while(get_string() == 0) ;
    if ((str[0] == 'y') || (str[0] == 'Y')) {
        result = Em_EEPROM_Erase() ;
        if (result != CY_EM_EEPROM_SUCCESS) {
            print("Em_EEPROM Erased\r\n") ;
        } else {
            print_em_eprom_error(result) ;
        } 
    } else {
        print("Em_EEPROM has not been touched\r\n") ;
    }
}

void do_stop(char *arg) 
{
    int argc ;
    uint16_t x ;
    argc = sscanf(arg,  "%*s %hd", &x) ;
    if (argc != 1) {
        x = 0x07 ;
    }
    if (x == 0x07) {
        Control_Reg_Write(0) ;
    }
    if (x & 0x01) {
        Counter1_Stop() ;
        counter[0].status = COUNTER_STOPPED ;
    }
    if (x & 0x02) {
        Counter2_Stop() ;
        counter[1].status = COUNTER_STOPPED ;
    }
    if (x & 0x04) {
        Counter3_Stop() ;
        counter[2].status = COUNTER_STOPPED ;
    }
}

void do_start(char *arg) 
{
    int argc, x ;
    argc = sscanf(arg, "%*s %d", &x) ;
    if (argc != 1) {
        x = 0x07 ;
    }

    if (x == 0x07) {
        Control_Reg_Write(0) ;
    }
    if (x & 0x01) {
        Counter1_Enable() ;
        counter[0].status = COUNTER_RUNNING ;
    }
    if (x & 0x02) {
        Counter2_Enable() ;
        counter[1].status = COUNTER_RUNNING ;
    }
    if (x & 0x04) {
        Counter3_Enable() ;
        counter[2].status = COUNTER_RUNNING ;
    }
    if (x == 0x07) {
        Control_Reg_Write(1) ;
    }
}

void do_period(char *arg) 
{
    int argc ;
    uint16_t period, x ;
    
    argc = sscanf(arg, "%*s %hd %hd", &x, &period) ;
    if (argc != 2) {
        period = x ;
        x = 0x07 ;
    }

    if (period > 0) {
        period = period - 1 ; // as counter starts from 0, period value will be 99 for period 100
    }

    if (x == 0x07) {
        Control_Reg_Write(0) ;
    }
    if (x & 0x01) {
        counter[0].period = period ;
        Counter1_Stop() ;
        Counter1_WritePeriod(period) ;
        Counter1_WriteCounter(0) ;
        if (counter[0].status == COUNTER_RUNNING) {
            Counter1_Enable() ;
        }
    }
    if (x & 0x02) {
        counter[1].period = period ;
        Counter2_Stop() ;
        Counter2_WritePeriod(period) ;
        Counter2_WriteCounter(0) ;
        if (counter[1].status == COUNTER_RUNNING) {
            Counter2_Enable() ;
        }
    }
    if (x & 0x04) {
        counter[2].period = period ;
        Counter3_Stop() ;
        Counter3_WritePeriod(period) ;
        Counter3_WriteCounter(0) ;
        if (counter[2].status == COUNTER_RUNNING) {
            Counter3_Enable() ;
        }
    }
    if (x == 0x07) {
        Control_Reg_Write(1) ;
    }
}

void do_compare(char *arg) 
{
    int argc ;
    uint16_t x, compare ;
    argc = sscanf(arg, "%*s %hd %hd", &x, &compare) ;
    if (argc != 2) {
        compare = x ;
        x = 0x07 ;
    }

    if (compare > 0) {
        compare = compare - 1 ; // as counter starts from 0, compare value will be 99 for compare 100
    }
    
    if (x == 0x07) {
        Control_Reg_Write(0) ;
    }
    if (x & 0x01) {
        counter[0].compare = compare ;
        Counter1_Stop() ;
        Counter1_WriteCompare(compare) ;
        if (counter[0].status == COUNTER_RUNNING) {
            Counter1_Enable() ;
        }
    }
    if (x & 0x02) {
        counter[1].compare = compare ;
        Counter2_Stop() ;
        Counter2_WriteCompare(compare) ;
        if (counter[1].status == COUNTER_RUNNING) {
            Counter2_Enable() ;
        }
    }
    if (x & 0x04) {
        counter[2].compare = compare ;
        Counter3_Stop() ;
        Counter3_WriteCompare(compare) ;
        if (counter[2].status == COUNTER_RUNNING) {
            Counter3_Enable() ;
        }
    }
    if (x == 0x07) {
        Control_Reg_Write(1) ;
    }
}