#include "project.h"
#include "stdio.h"
#include "tty_utils.h"
#include "em_EEPROM_utils.h"
#include "cmd_func.h"
    
void list_counter(void)
{
    int i ;
    for (i = 0 ; i < NUM_COUNTER ; i++ ) {
        sprintf(str, "Counter%d: period=%5d compare=%5d\n",
                i+1,counter[i].period, counter[i].compare) ;
        print(str) ;
    }
}

void init_counter_values(void)
{
    int i ;
    load_pwm() ;
    if (is_eeprom_empty(counter)) {
        print("No data stored in Em_EEPROM, default value will be used\n") ;
        for (i = 0 ; i < NUM_COUNTER ; i++) {
            counter[i].period  = DEFAULT_PERIOD ;
            counter[i].compare = DEFAULT_COMPARE ;
        }
    }
    Counter1_WritePeriod(counter[0].period) ;
    Counter1_WriteCompare(counter[0].compare) ;
    counter[0].status = COUNTER_STOPPED ;
    Counter2_WritePeriod(counter[1].period) ;
    Counter2_WriteCompare(counter[1].compare) ;
    counter[1].status = COUNTER_STOPPED ;
    Counter3_WritePeriod(counter[2].period) ;
    Counter3_WriteCompare(counter[2].compare) ;
    counter[2].status = COUNTER_STOPPED ;
}

void init_hardware(void)
{   
    UART_Start() ;
    tty_init() ;
    splash("Multiple PWM Test") ;
    
    Counter1_Init() ;
    Counter2_Init() ;
    Counter3_Init() ;
    
    Clk25KHz_Gen_Start() ;
    
    Control_Reg_Write(0) ;
    
    init_em_eeprom() ;
    init_counter_values() ;
    
    Control_Reg_Write(1) ;
    CyGlobalIntEnable; /* Enable global interrupts. */    
}

int main(void)
{
    func_ptr_type func ;
    
    init_hardware() ;
    
    do_list(0) ;
    
    do_start(0) ;
        
    prompt() ;
    
    for(;;)
    {
        if (get_line()) {
            func = get_func(str) ;
            if (func) {
                func(str) ;
            } else {
                print("Unknown command: ") ;
                print(str) ;
                print("\r\n") ;
                do_help(0) ;
            }
            prompt() ;
        }
    }
}

/* [] END OF FILE */
