#include "em_EEPROM_utils.h"
#include "tty_utils.h"
#include "stdio.h"

/* EEPROM storage in work flash, this is defined in Em_EEPROM.c*/
#if defined (__ICCARM__)
#pragma data_alignment = CY_FLASH_SIZEOF_ROW
const uint8_t Em_EEPROM_em_EepromStorage[Em_EEPROM_PHYSICAL_SIZE] = {0u};
#else
const uint8_t Em_EEPROM_em_EepromStorage[Em_EEPROM_PHYSICAL_SIZE]
__ALIGNED(CY_FLASH_SIZEOF_ROW) = {0u};
#endif /* defined (__ICCARM__) */

cy_en_em_eeprom_status_t eepromReturnValue;

pwm_counter_type counter[NUM_COUNTER] ;

void print_em_eprom_error(cy_en_em_eeprom_status_t status)
{
    switch(status) {
    case CY_EM_EEPROM_SUCCESS:      print("No Error\n") ; break ;
    case CY_EM_EEPROM_BAD_PARAM:    print("The input parameter is invalid\n") ; break ;
    case CY_EM_EEPROM_BAD_CHECKSUM: print("The data in EEPROM is correupted\n") ; break ;
    case CY_EM_EEPROM_BAD_DATA:     print("Failed to place the EEPROM in flash\n") ; break ;
    case CY_EM_EEPROM_WRITE_FAIL:   print("Write to EEPROM failed\n") ; break ;
    default:
        sprintf(str, "EEPROM Unknown Error %d\n", status) ; 
        print(str) ;
        break ;
    }
}

cy_en_em_eeprom_status_t init_em_eeprom(void)
{
    /*Initalize EEPROM with the start address of the memory location*/
    eepromReturnValue = Em_EEPROM_Init((uint32_t)Em_EEPROM_em_EepromStorage);

    return( eepromReturnValue ) ;
}

cy_en_em_eeprom_status_t load_pwm(void)
{
    cy_en_em_eeprom_status_t result ;
    result = Em_EEPROM_Read(0, counter, NUM_COUNTER * 6) ;
    return( result ) ;
}

cy_en_em_eeprom_status_t save_pwm(void)
{
    cy_en_em_eeprom_status_t result ;
    result = Em_EEPROM_Write(0, counter, NUM_COUNTER * 6) ;
    return( result ) ;
}

int is_eeprom_empty(pwm_counter_type *counter)
{
    int sum = 0 ;
    int i = 0 ;
    for (i = 0 ; i < NUM_COUNTER ; i++ ) {
        sum += (counter[i].period + counter[i].compare) ;
    }
    return( sum == 0 ) ;
}


